# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_shared_enums.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_shared_enums.proto',
  package='dota',
  syntax='proto2',
  serialized_options=_b('H\001\220\001\000'),
  serialized_pb=_b('\n\x17\x64ota_shared_enums.proto\x12\x04\x64ota\"\xbf\x01\n\x18\x43\x44OTAClientHardwareSpecs\x12\x1a\n\x12logical_processors\x18\x01 \x01(\r\x12\x1d\n\x15\x63pu_cycles_per_second\x18\x02 \x01(\x06\x12\x1d\n\x15total_physical_memory\x18\x03 \x01(\x06\x12\x14\n\x0cis_64_bit_os\x18\x04 \x01(\x08\x12\x1a\n\x12upload_measurement\x18\x05 \x01(\x04\x12\x17\n\x0fprefer_not_host\x18\x06 \x01(\x08\"\xe2\x03\n\rCDOTASaveGame\x12\x10\n\x08match_id\x18\x05 \x01(\x04\x12\x11\n\tsave_time\x18\x02 \x01(\r\x12+\n\x07players\x18\x03 \x03(\x0b\x32\x1a.dota.CDOTASaveGame.Player\x12\x38\n\x0esave_instances\x18\x04 \x03(\x0b\x32 .dota.CDOTASaveGame.SaveInstance\x1a^\n\x06Player\x12\x38\n\x04team\x18\x01 \x01(\x0e\x32\x12.dota.DOTA_GC_TEAM:\x16\x44OTA_GC_TEAM_GOOD_GUYS\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04hero\x18\x03 \x01(\t\x1a\xe4\x01\n\x0cSaveInstance\x12\x11\n\tgame_time\x18\x02 \x01(\r\x12\x13\n\x0bteam1_score\x18\x03 \x01(\r\x12\x13\n\x0bteam2_score\x18\x04 \x01(\r\x12J\n\x10player_positions\x18\x05 \x03(\x0b\x32\x30.dota.CDOTASaveGame.SaveInstance.PlayerPositions\x12\x0f\n\x07save_id\x18\x06 \x01(\r\x12\x11\n\tsave_time\x18\x07 \x01(\r\x1a\'\n\x0fPlayerPositions\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"\xe2\x0e\n\x16\x43MsgDOTACombatLogEntry\x12@\n\x04type\x18\x01 \x01(\x0e\x32\x1a.dota.DOTA_COMBATLOG_TYPES:\x16\x44OTA_COMBATLOG_INVALID\x12\x13\n\x0btarget_name\x18\x02 \x01(\r\x12\x1a\n\x12target_source_name\x18\x03 \x01(\r\x12\x15\n\rattacker_name\x18\x04 \x01(\r\x12\x1a\n\x12\x64\x61mage_source_name\x18\x05 \x01(\r\x12\x16\n\x0einflictor_name\x18\x06 \x01(\r\x12\x1c\n\x14is_attacker_illusion\x18\x07 \x01(\x08\x12\x18\n\x10is_attacker_hero\x18\x08 \x01(\x08\x12\x1a\n\x12is_target_illusion\x18\t \x01(\x08\x12\x16\n\x0eis_target_hero\x18\n \x01(\x08\x12\x1a\n\x12is_visible_radiant\x18\x0b \x01(\x08\x12\x17\n\x0fis_visible_dire\x18\x0c \x01(\x08\x12\r\n\x05value\x18\r \x01(\r\x12\x0e\n\x06health\x18\x0e \x01(\x05\x12\x11\n\ttimestamp\x18\x0f \x01(\x02\x12\x15\n\rstun_duration\x18\x10 \x01(\x02\x12\x15\n\rslow_duration\x18\x11 \x01(\x02\x12\x1c\n\x14is_ability_toggle_on\x18\x12 \x01(\x08\x12\x1d\n\x15is_ability_toggle_off\x18\x13 \x01(\x08\x12\x15\n\rability_level\x18\x14 \x01(\r\x12\x12\n\nlocation_x\x18\x15 \x01(\x02\x12\x12\n\nlocation_y\x18\x16 \x01(\x02\x12\x13\n\x0bgold_reason\x18\x17 \x01(\r\x12\x15\n\rtimestamp_raw\x18\x18 \x01(\x02\x12\x19\n\x11modifier_duration\x18\x19 \x01(\x02\x12\x11\n\txp_reason\x18\x1a \x01(\r\x12\x11\n\tlast_hits\x18\x1b \x01(\r\x12\x15\n\rattacker_team\x18\x1c \x01(\r\x12\x13\n\x0btarget_team\x18\x1d \x01(\r\x12\x18\n\x10obs_wards_placed\x18\x1e \x01(\r\x12\x16\n\x0e\x61ssist_player0\x18\x1f \x01(\r\x12\x16\n\x0e\x61ssist_player1\x18  \x01(\r\x12\x16\n\x0e\x61ssist_player2\x18! \x01(\r\x12\x16\n\x0e\x61ssist_player3\x18\" \x01(\r\x12\x13\n\x0bstack_count\x18# \x01(\r\x12\x17\n\x0fhidden_modifier\x18$ \x01(\x08\x12\x1a\n\x12is_target_building\x18% \x01(\x08\x12\x19\n\x11neutral_camp_type\x18& \x01(\r\x12\x11\n\trune_type\x18\' \x01(\r\x12\x16\n\x0e\x61ssist_players\x18( \x03(\r\x12\x14\n\x0cis_heal_save\x18) \x01(\x08\x12\x1b\n\x13is_ultimate_ability\x18* \x01(\x08\x12\x1b\n\x13\x61ttacker_hero_level\x18+ \x01(\r\x12\x19\n\x11target_hero_level\x18, \x01(\r\x12\x0b\n\x03xpm\x18- \x01(\r\x12\x0b\n\x03gpm\x18. \x01(\r\x12\x16\n\x0e\x65vent_location\x18/ \x01(\r\x12\x16\n\x0etarget_is_self\x18\x30 \x01(\x08\x12\x13\n\x0b\x64\x61mage_type\x18\x31 \x01(\r\x12\x1d\n\x15invisibility_modifier\x18\x32 \x01(\x08\x12\x17\n\x0f\x64\x61mage_category\x18\x33 \x01(\r\x12\x10\n\x08networth\x18\x34 \x01(\r\x12\x15\n\rbuilding_type\x18\x35 \x01(\r\x12!\n\x19modifier_elapsed_duration\x18\x36 \x01(\x02\x12\x18\n\x10silence_modifier\x18\x37 \x01(\x08\x12\x1b\n\x13heal_from_lifesteal\x18\x38 \x01(\x08\x12\x17\n\x0fmodifier_purged\x18\x39 \x01(\x08\x12\x14\n\x0cspell_evaded\x18: \x01(\x08\x12\"\n\x1amotion_controller_modifier\x18; \x01(\x08\x12\x17\n\x0flong_range_kill\x18< \x01(\x08\x12\x1e\n\x16modifier_purge_ability\x18= \x01(\r\x12\x1a\n\x12modifier_purge_npc\x18> \x01(\r\x12\x15\n\rroot_modifier\x18? \x01(\x08\x12\x1e\n\x16total_unit_death_count\x18@ \x01(\r\x12\x15\n\raura_modifier\x18\x41 \x01(\x08\x12\x1d\n\x15\x61rmor_debuff_modifier\x18\x42 \x01(\x08\x12#\n\x1bno_physical_damage_modifier\x18\x43 \x01(\x08\x12\x18\n\x10modifier_ability\x18\x44 \x01(\r\x12\x17\n\x0fmodifier_hidden\x18\x45 \x01(\x08\x12#\n\x1binflictor_is_stolen_ability\x18\x46 \x01(\x08\x12\x18\n\x10kill_eater_event\x18G \x01(\r\x12\x19\n\x11unit_status_label\x18H \x01(\r\x12\x1e\n\x16spell_generated_attack\x18I \x01(\x08*\x9a\x05\n\rDOTA_GameMode\x12\x16\n\x12\x44OTA_GAMEMODE_NONE\x10\x00\x12\x14\n\x10\x44OTA_GAMEMODE_AP\x10\x01\x12\x14\n\x10\x44OTA_GAMEMODE_CM\x10\x02\x12\x14\n\x10\x44OTA_GAMEMODE_RD\x10\x03\x12\x14\n\x10\x44OTA_GAMEMODE_SD\x10\x04\x12\x14\n\x10\x44OTA_GAMEMODE_AR\x10\x05\x12\x17\n\x13\x44OTA_GAMEMODE_INTRO\x10\x06\x12\x14\n\x10\x44OTA_GAMEMODE_HW\x10\x07\x12\x1c\n\x18\x44OTA_GAMEMODE_REVERSE_CM\x10\x08\x12\x16\n\x12\x44OTA_GAMEMODE_XMAS\x10\t\x12\x1a\n\x16\x44OTA_GAMEMODE_TUTORIAL\x10\n\x12\x14\n\x10\x44OTA_GAMEMODE_MO\x10\x0b\x12\x14\n\x10\x44OTA_GAMEMODE_LP\x10\x0c\x12\x17\n\x13\x44OTA_GAMEMODE_POOL1\x10\r\x12\x14\n\x10\x44OTA_GAMEMODE_FH\x10\x0e\x12\x18\n\x14\x44OTA_GAMEMODE_CUSTOM\x10\x0f\x12\x14\n\x10\x44OTA_GAMEMODE_CD\x10\x10\x12\x14\n\x10\x44OTA_GAMEMODE_BD\x10\x11\x12\x1f\n\x1b\x44OTA_GAMEMODE_ABILITY_DRAFT\x10\x12\x12\x17\n\x13\x44OTA_GAMEMODE_EVENT\x10\x13\x12\x16\n\x12\x44OTA_GAMEMODE_ARDM\x10\x14\x12\x18\n\x14\x44OTA_GAMEMODE_1V1MID\x10\x15\x12\x1b\n\x17\x44OTA_GAMEMODE_ALL_DRAFT\x10\x16\x12\x17\n\x13\x44OTA_GAMEMODE_TURBO\x10\x17\x12\x1a\n\x16\x44OTA_GAMEMODE_MUTATION\x10\x18\x12#\n\x1f\x44OTA_GAMEMODE_COACHES_CHALLENGE\x10\x19*\xec\x03\n\x0e\x44OTA_GameState\x12\x1d\n\x19\x44OTA_GAMERULES_STATE_INIT\x10\x00\x12\x31\n-DOTA_GAMERULES_STATE_WAIT_FOR_PLAYERS_TO_LOAD\x10\x01\x12\'\n#DOTA_GAMERULES_STATE_HERO_SELECTION\x10\x02\x12&\n\"DOTA_GAMERULES_STATE_STRATEGY_TIME\x10\x03\x12!\n\x1d\x44OTA_GAMERULES_STATE_PRE_GAME\x10\x04\x12)\n%DOTA_GAMERULES_STATE_GAME_IN_PROGRESS\x10\x05\x12\"\n\x1e\x44OTA_GAMERULES_STATE_POST_GAME\x10\x06\x12#\n\x1f\x44OTA_GAMERULES_STATE_DISCONNECT\x10\x07\x12&\n\"DOTA_GAMERULES_STATE_TEAM_SHOWCASE\x10\x08\x12*\n&DOTA_GAMERULES_STATE_CUSTOM_GAME_SETUP\x10\t\x12-\n)DOTA_GAMERULES_STATE_WAIT_FOR_MAP_TO_LOAD\x10\n\x12\x1d\n\x19\x44OTA_GAMERULES_STATE_LAST\x10\x0b*\xb6\x01\n\x0c\x44OTA_GC_TEAM\x12\x1a\n\x16\x44OTA_GC_TEAM_GOOD_GUYS\x10\x00\x12\x19\n\x15\x44OTA_GC_TEAM_BAD_GUYS\x10\x01\x12\x1c\n\x18\x44OTA_GC_TEAM_BROADCASTER\x10\x02\x12\x1a\n\x16\x44OTA_GC_TEAM_SPECTATOR\x10\x03\x12\x1c\n\x18\x44OTA_GC_TEAM_PLAYER_POOL\x10\x04\x12\x17\n\x13\x44OTA_GC_TEAM_NOTEAM\x10\x05*\x9e\x06\n\x06\x45\x45vent\x12\x11\n\rEVENT_ID_NONE\x10\x00\x12\x15\n\x11\x45VENT_ID_DIRETIDE\x10\x01\x12\x1c\n\x18\x45VENT_ID_SPRING_FESTIVAL\x10\x02\x12\x1b\n\x17\x45VENT_ID_FROSTIVUS_2013\x10\x03\x12\x1c\n\x18\x45VENT_ID_COMPENDIUM_2014\x10\x04\x12\x1a\n\x16\x45VENT_ID_NEXON_PC_BANG\x10\x05\x12\x1a\n\x16\x45VENT_ID_PWRD_DAC_2015\x10\x06\x12\x1b\n\x17\x45VENT_ID_NEW_BLOOM_2015\x10\x07\x12\x1f\n\x1b\x45VENT_ID_INTERNATIONAL_2015\x10\x08\x12\x1c\n\x18\x45VENT_ID_FALL_MAJOR_2015\x10\t\x12\x16\n\x12\x45VENT_ID_ORACLE_PA\x10\n\x12$\n EVENT_ID_NEW_BLOOM_2015_PREBEAST\x10\x0b\x12\x16\n\x12\x45VENT_ID_FROSTIVUS\x10\x0c\x12\x1e\n\x1a\x45VENT_ID_WINTER_MAJOR_2016\x10\r\x12\x1f\n\x1b\x45VENT_ID_INTERNATIONAL_2016\x10\x0e\x12\x1c\n\x18\x45VENT_ID_FALL_MAJOR_2016\x10\x0f\x12\x1e\n\x1a\x45VENT_ID_WINTER_MAJOR_2017\x10\x10\x12\x1b\n\x17\x45VENT_ID_NEW_BLOOM_2017\x10\x11\x12\x1f\n\x1b\x45VENT_ID_INTERNATIONAL_2017\x10\x12\x12\x1e\n\x1a\x45VENT_ID_PLUS_SUBSCRIPTION\x10\x13\x12\x1d\n\x19\x45VENT_ID_SINGLES_DAY_2017\x10\x14\x12\x1b\n\x17\x45VENT_ID_FROSTIVUS_2017\x10\x15\x12\x1f\n\x1b\x45VENT_ID_INTERNATIONAL_2018\x10\x16\x12\x1b\n\x17\x45VENT_ID_FROSTIVUS_2018\x10\x17\x12\x1b\n\x17\x45VENT_ID_NEW_BLOOM_2019\x10\x18\x12\x1f\n\x1b\x45VENT_ID_INTERNATIONAL_2019\x10\x19\x12\x12\n\x0e\x45VENT_ID_COUNT\x10\x1a*\xa8\x02\n\x12\x44OTALeaverStatus_t\x12\x14\n\x10\x44OTA_LEAVER_NONE\x10\x00\x12\x1c\n\x18\x44OTA_LEAVER_DISCONNECTED\x10\x01\x12%\n!DOTA_LEAVER_DISCONNECTED_TOO_LONG\x10\x02\x12\x19\n\x15\x44OTA_LEAVER_ABANDONED\x10\x03\x12\x13\n\x0f\x44OTA_LEAVER_AFK\x10\x04\x12\x1f\n\x1b\x44OTA_LEAVER_NEVER_CONNECTED\x10\x05\x12(\n$DOTA_LEAVER_NEVER_CONNECTED_TOO_LONG\x10\x06\x12\"\n\x1e\x44OTA_LEAVER_FAILED_TO_READY_UP\x10\x07\x12\x18\n\x14\x44OTA_LEAVER_DECLINED\x10\x08*\x9e\x02\n\x15\x44OTAConnectionState_t\x12!\n\x1d\x44OTA_CONNECTION_STATE_UNKNOWN\x10\x00\x12+\n\'DOTA_CONNECTION_STATE_NOT_YET_CONNECTED\x10\x01\x12#\n\x1f\x44OTA_CONNECTION_STATE_CONNECTED\x10\x02\x12&\n\"DOTA_CONNECTION_STATE_DISCONNECTED\x10\x03\x12#\n\x1f\x44OTA_CONNECTION_STATE_ABANDONED\x10\x04\x12!\n\x1d\x44OTA_CONNECTION_STATE_LOADING\x10\x05\x12 \n\x1c\x44OTA_CONNECTION_STATE_FAILED\x10\x06*\x8c\x01\n\rFantasy_Roles\x12\x1a\n\x16\x46\x41NTASY_ROLE_UNDEFINED\x10\x00\x12\x15\n\x11\x46\x41NTASY_ROLE_CORE\x10\x01\x12\x18\n\x14\x46\x41NTASY_ROLE_SUPPORT\x10\x02\x12\x18\n\x14\x46\x41NTASY_ROLE_OFFLANE\x10\x03\x12\x14\n\x10\x46\x41NTASY_ROLE_MID\x10\x04*\x8a\x01\n\x12\x46\x61ntasy_Team_Slots\x12\x15\n\x11\x46\x41NTASY_SLOT_NONE\x10\x00\x12\x15\n\x11\x46\x41NTASY_SLOT_CORE\x10\x01\x12\x18\n\x14\x46\x41NTASY_SLOT_SUPPORT\x10\x02\x12\x14\n\x10\x46\x41NTASY_SLOT_ANY\x10\x03\x12\x16\n\x12\x46\x41NTASY_SLOT_BENCH\x10\x04*\xdd\x02\n\x16\x46\x61ntasy_Selection_Mode\x12\x1d\n\x19\x46\x41NTASY_SELECTION_INVALID\x10\x00\x12\x1c\n\x18\x46\x41NTASY_SELECTION_LOCKED\x10\x01\x12\x1d\n\x19\x46\x41NTASY_SELECTION_SHUFFLE\x10\x02\x12\x1f\n\x1b\x46\x41NTASY_SELECTION_FREE_PICK\x10\x03\x12\x1b\n\x17\x46\x41NTASY_SELECTION_ENDED\x10\x04\x12 \n\x1c\x46\x41NTASY_SELECTION_PRE_SEASON\x10\x05\x12\x1f\n\x1b\x46\x41NTASY_SELECTION_PRE_DRAFT\x10\x06\x12\x1e\n\x1a\x46\x41NTASY_SELECTION_DRAFTING\x10\x07\x12$\n FANTASY_SELECTION_REGULAR_SEASON\x10\x08\x12 \n\x1c\x46\x41NTASY_SELECTION_CARD_BASED\x10\t*\x9c\x05\n\x15\x44OTAChatChannelType_t\x12\x1c\n\x18\x44OTAChannelType_Regional\x10\x00\x12\x1a\n\x16\x44OTAChannelType_Custom\x10\x01\x12\x19\n\x15\x44OTAChannelType_Party\x10\x02\x12\x19\n\x15\x44OTAChannelType_Lobby\x10\x03\x12\x18\n\x14\x44OTAChannelType_Team\x10\x04\x12\x19\n\x15\x44OTAChannelType_Guild\x10\x05\x12\x1b\n\x17\x44OTAChannelType_Fantasy\x10\x06\x12\x1b\n\x17\x44OTAChannelType_Whisper\x10\x07\x12\x1b\n\x17\x44OTAChannelType_Console\x10\x08\x12\x17\n\x13\x44OTAChannelType_Tab\x10\t\x12\x1b\n\x17\x44OTAChannelType_Invalid\x10\n\x12\x1b\n\x17\x44OTAChannelType_GameAll\x10\x0b\x12\x1e\n\x1a\x44OTAChannelType_GameAllies\x10\x0c\x12!\n\x1d\x44OTAChannelType_GameSpectator\x10\r\x12\x18\n\x14\x44OTAChannelType_Cafe\x10\x0f\x12\x1e\n\x1a\x44OTAChannelType_CustomGame\x10\x10\x12\x1b\n\x17\x44OTAChannelType_Private\x10\x11\x12\x1c\n\x18\x44OTAChannelType_PostGame\x10\x12\x12\x1d\n\x19\x44OTAChannelType_BattleCup\x10\x13\x12!\n\x1d\x44OTAChannelType_HLTVSpectator\x10\x14\x12\x1e\n\x1a\x44OTAChannelType_GameEvents\x10\x15\x12\x1a\n\x16\x44OTAChannelType_Trivia\x10\x16*\x84\x02\n\x14\x45ProfileCardSlotType\x12 \n\x1ck_EProfileCardSlotType_Empty\x10\x00\x12\x1f\n\x1bk_EProfileCardSlotType_Stat\x10\x01\x12!\n\x1dk_EProfileCardSlotType_Trophy\x10\x02\x12\x1f\n\x1bk_EProfileCardSlotType_Item\x10\x03\x12\x1f\n\x1bk_EProfileCardSlotType_Hero\x10\x04\x12#\n\x1fk_EProfileCardSlotType_Emoticon\x10\x05\x12\x1f\n\x1bk_EProfileCardSlotType_Team\x10\x06*\x95\x01\n\x17\x45MatchGroupServerStatus\x12 \n\x1ck_EMatchGroupServerStatus_OK\x10\x00\x12\x31\n-k_EMatchGroupServerStatus_LimitedAvailability\x10\x01\x12%\n!k_EMatchGroupServerStatus_Offline\x10\x02*O\n\x0c\x44OTA_CM_PICK\x12\x12\n\x0e\x44OTA_CM_RANDOM\x10\x00\x12\x15\n\x11\x44OTA_CM_GOOD_GUYS\x10\x01\x12\x14\n\x10\x44OTA_CM_BAD_GUYS\x10\x02*\x8b\x01\n\x16\x44OTALowPriorityBanType\x12!\n\x1d\x44OTA_LOW_PRIORITY_BAN_ABANDON\x10\x00\x12!\n\x1d\x44OTA_LOW_PRIORITY_BAN_REPORTS\x10\x01\x12+\n\'DOTA_LOW_PRIORITY_BAN_SECONDARY_ABANDON\x10\x02*}\n\x13\x44OTALobbyReadyState\x12\"\n\x1e\x44OTALobbyReadyState_UNDECLARED\x10\x00\x12 \n\x1c\x44OTALobbyReadyState_ACCEPTED\x10\x01\x12 \n\x1c\x44OTALobbyReadyState_DECLINED\x10\x02*D\n\x0f\x44OTAGameVersion\x12\x18\n\x14GAME_VERSION_CURRENT\x10\x00\x12\x17\n\x13GAME_VERSION_STABLE\x10\x01*\x98\x04\n\x13\x44OTAJoinLobbyResult\x12\x1c\n\x18\x44OTA_JOIN_RESULT_SUCCESS\x10\x00\x12$\n DOTA_JOIN_RESULT_ALREADY_IN_GAME\x10\x01\x12\"\n\x1e\x44OTA_JOIN_RESULT_INVALID_LOBBY\x10\x02\x12\'\n#DOTA_JOIN_RESULT_INCORRECT_PASSWORD\x10\x03\x12\"\n\x1e\x44OTA_JOIN_RESULT_ACCESS_DENIED\x10\x04\x12\"\n\x1e\x44OTA_JOIN_RESULT_GENERIC_ERROR\x10\x05\x12&\n\"DOTA_JOIN_RESULT_INCORRECT_VERSION\x10\x06\x12\"\n\x1e\x44OTA_JOIN_RESULT_IN_TEAM_PARTY\x10\x07\x12#\n\x1f\x44OTA_JOIN_RESULT_NO_LOBBY_FOUND\x10\x08\x12\x1f\n\x1b\x44OTA_JOIN_RESULT_LOBBY_FULL\x10\t\x12\x32\n.DOTA_JOIN_RESULT_CUSTOM_GAME_INCORRECT_VERSION\x10\n\x12\x1c\n\x18\x44OTA_JOIN_RESULT_TIMEOUT\x10\x0b\x12)\n%DOTA_JOIN_RESULT_CUSTOM_GAME_COOLDOWN\x10\x0c\x12\x19\n\x15\x44OTA_JOIN_RESULT_BUSY\x10\r*q\n\x1a\x44OTASelectionPriorityRules\x12\'\n#k_DOTASelectionPriorityRules_Manual\x10\x00\x12*\n&k_DOTASelectionPriorityRules_Automatic\x10\x01*\xf6\x01\n\x1b\x44OTASelectionPriorityChoice\x12)\n%k_DOTASelectionPriorityChoice_Invalid\x10\x00\x12+\n\'k_DOTASelectionPriorityChoice_FirstPick\x10\x01\x12,\n(k_DOTASelectionPriorityChoice_SecondPick\x10\x02\x12)\n%k_DOTASelectionPriorityChoice_Radiant\x10\x03\x12&\n\"k_DOTASelectionPriorityChoice_Dire\x10\x04*b\n\rDOTAMatchVote\x12\x19\n\x15\x44OTAMatchVote_INVALID\x10\x00\x12\x1a\n\x16\x44OTAMatchVote_POSITIVE\x10\x01\x12\x1a\n\x16\x44OTAMatchVote_NEGATIVE\x10\x02*\x83\x02\n\x17\x44OTA_LobbyMemberXPBonus\x12#\n\x1f\x44OTA_LobbyMemberXPBonus_DEFAULT\x10\x00\x12*\n&DOTA_LobbyMemberXPBonus_BATTLE_BOOSTER\x10\x01\x12\'\n#DOTA_LobbyMemberXPBonus_SHARE_BONUS\x10\x02\x12!\n\x1d\x44OTA_LobbyMemberXPBonus_PARTY\x10\x03\x12\'\n#DOTA_LobbyMemberXPBonus_RECRUITMENT\x10\x04\x12\"\n\x1e\x44OTA_LobbyMemberXPBonus_PCBANG\x10\x05*x\n\x13\x44OTALobbyVisibility\x12\x1e\n\x1a\x44OTALobbyVisibility_Public\x10\x00\x12\x1f\n\x1b\x44OTALobbyVisibility_Friends\x10\x01\x12 \n\x1c\x44OTALobbyVisibility_Unlisted\x10\x02*\xa3\x03\n\x12\x45\x44OTAPlayerMMRType\x12 \n\x1ck_EDOTAPlayerMMRType_Invalid\x10\x00\x12&\n\"k_EDOTAPlayerMMRType_GeneralHidden\x10\x01\x12/\n+k_EDOTAPlayerMMRType_GeneralCompetitive2019\x10\x03\x12,\n(k_EDOTAPlayerMMRType_SoloCompetitive2019\x10\x04\x12.\n*k_EDOTAPlayerMMRType_1v1Competitive_UNUSED\x10\x05\x12.\n*k_EDOTAPlayerMMRType_GeneralSeasonalRanked\x10\x06\x12+\n\'k_EDOTAPlayerMMRType_SoloSeasonalRanked\x10\x07\x12)\n%k_EDOTAPlayerMMRType_Competitive_Core\x10\x08\x12,\n(k_EDOTAPlayerMMRType_Competitive_Support\x10\t*\x87\x03\n\tMatchType\x12\x15\n\x11MATCH_TYPE_CASUAL\x10\x00\x12\x18\n\x14MATCH_TYPE_COOP_BOTS\x10\x01\x12!\n\x1dMATCH_TYPE_LEGACY_TEAM_RANKED\x10\x02\x12 \n\x1cMATCH_TYPE_LEGACY_SOLO_QUEUE\x10\x03\x12\x1a\n\x16MATCH_TYPE_COMPETITIVE\x10\x04\x12\x1e\n\x1aMATCH_TYPE_WEEKEND_TOURNEY\x10\x05\x12\x19\n\x15MATCH_TYPE_CASUAL_1V1\x10\x06\x12\x14\n\x10MATCH_TYPE_EVENT\x10\x07\x12\x1e\n\x1aMATCH_TYPE_SEASONAL_RANKED\x10\x08\x12 \n\x1cMATCH_TYPE_LOWPRI_DEPRECATED\x10\t\x12\x1a\n\x16MATCH_TYPE_STEAM_GROUP\x10\n\x12\x17\n\x13MATCH_TYPE_MUTATION\x10\x0b\x12 \n\x1cMATCH_TYPE_COACHES_CHALLENGE\x10\x0c*\x84\x02\n\x11\x44OTABotDifficulty\x12\x1a\n\x16\x42OT_DIFFICULTY_PASSIVE\x10\x00\x12\x17\n\x13\x42OT_DIFFICULTY_EASY\x10\x01\x12\x19\n\x15\x42OT_DIFFICULTY_MEDIUM\x10\x02\x12\x17\n\x13\x42OT_DIFFICULTY_HARD\x10\x03\x12\x19\n\x15\x42OT_DIFFICULTY_UNFAIR\x10\x04\x12\x1a\n\x16\x42OT_DIFFICULTY_INVALID\x10\x05\x12\x19\n\x15\x42OT_DIFFICULTY_EXTRA1\x10\x06\x12\x19\n\x15\x42OT_DIFFICULTY_EXTRA2\x10\x07\x12\x19\n\x15\x42OT_DIFFICULTY_EXTRA3\x10\x08*\x93\x06\n\rDOTA_BOT_MODE\x12\x16\n\x12\x44OTA_BOT_MODE_NONE\x10\x00\x12\x18\n\x14\x44OTA_BOT_MODE_LANING\x10\x01\x12\x18\n\x14\x44OTA_BOT_MODE_ATTACK\x10\x02\x12\x16\n\x12\x44OTA_BOT_MODE_ROAM\x10\x03\x12\x19\n\x15\x44OTA_BOT_MODE_RETREAT\x10\x04\x12\x1d\n\x19\x44OTA_BOT_MODE_SECRET_SHOP\x10\x05\x12\x1b\n\x17\x44OTA_BOT_MODE_SIDE_SHOP\x10\x06\x12\x16\n\x12\x44OTA_BOT_MODE_RUNE\x10\x07\x12 \n\x1c\x44OTA_BOT_MODE_PUSH_TOWER_TOP\x10\x08\x12 \n\x1c\x44OTA_BOT_MODE_PUSH_TOWER_MID\x10\t\x12 \n\x1c\x44OTA_BOT_MODE_PUSH_TOWER_BOT\x10\n\x12\"\n\x1e\x44OTA_BOT_MODE_DEFEND_TOWER_TOP\x10\x0b\x12\"\n\x1e\x44OTA_BOT_MODE_DEFEND_TOWER_MID\x10\x0c\x12\"\n\x1e\x44OTA_BOT_MODE_DEFEND_TOWER_BOT\x10\r\x12\x1a\n\x16\x44OTA_BOT_MODE_ASSEMBLE\x10\x0e\x12&\n\"DOTA_BOT_MODE_ASSEMBLE_WITH_HUMANS\x10\x0f\x12\x1b\n\x17\x44OTA_BOT_MODE_TEAM_ROAM\x10\x10\x12\x16\n\x12\x44OTA_BOT_MODE_FARM\x10\x11\x12\x1d\n\x19\x44OTA_BOT_MODE_DEFEND_ALLY\x10\x12\x12#\n\x1f\x44OTA_BOT_MODE_EVASIVE_MANEUVERS\x10\x13\x12\x18\n\x14\x44OTA_BOT_MODE_ROSHAN\x10\x14\x12\x16\n\x12\x44OTA_BOT_MODE_ITEM\x10\x15\x12\x16\n\x12\x44OTA_BOT_MODE_WARD\x10\x16\x12\x1b\n\x17\x44OTA_BOT_MODE_COMPANION\x10\x17\x12\x1f\n\x1b\x44OTA_BOT_MODE_TUTORIAL_BOSS\x10\x18\x12\x18\n\x14\x44OTA_BOT_MODE_MINION\x10\x19*\xf3\x01\n\x0eMatchLanguages\x12\x1a\n\x16MATCH_LANGUAGE_INVALID\x10\x00\x12\x1a\n\x16MATCH_LANGUAGE_ENGLISH\x10\x01\x12\x1a\n\x16MATCH_LANGUAGE_RUSSIAN\x10\x02\x12\x1a\n\x16MATCH_LANGUAGE_CHINESE\x10\x03\x12\x19\n\x15MATCH_LANGUAGE_KOREAN\x10\x04\x12\x1a\n\x16MATCH_LANGUAGE_SPANISH\x10\x05\x12\x1d\n\x19MATCH_LANGUAGE_PORTUGUESE\x10\x06\x12\x1b\n\x17MATCH_LANGUAGE_ENGLISH2\x10\x07*\xd8\x02\n\x1a\x45TourneyQueueDeadlineState\x12\'\n#k_ETourneyQueueDeadlineState_Normal\x10\x00\x12\'\n#k_ETourneyQueueDeadlineState_Missed\x10\x01\x12*\n&k_ETourneyQueueDeadlineState_ExpiredOK\x10\x02\x12+\n\'k_ETourneyQueueDeadlineState_SeekingBye\x10\x03\x12\x32\n.k_ETourneyQueueDeadlineState_EligibleForRefund\x10\x04\x12,\n\x1fk_ETourneyQueueDeadlineState_NA\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n)k_ETourneyQueueDeadlineState_ExpiringSoon\x10\x65*\xc7\x02\n\rEMatchOutcome\x12\x1b\n\x17k_EMatchOutcome_Unknown\x10\x00\x12\x1e\n\x1ak_EMatchOutcome_RadVictory\x10\x02\x12\x1f\n\x1bk_EMatchOutcome_DireVictory\x10\x03\x12\x33\n/k_EMatchOutcome_NotScored_PoorNetworkConditions\x10@\x12$\n k_EMatchOutcome_NotScored_Leaver\x10\x41\x12)\n%k_EMatchOutcome_NotScored_ServerCrash\x10\x42\x12*\n&k_EMatchOutcome_NotScored_NeverStarted\x10\x43\x12&\n\"k_EMatchOutcome_NotScored_Canceled\x10\x44*\x86\x01\n\tELaneType\x12\x15\n\x11LANE_TYPE_UNKNOWN\x10\x00\x12\x12\n\x0eLANE_TYPE_SAFE\x10\x01\x12\x11\n\rLANE_TYPE_OFF\x10\x02\x12\x11\n\rLANE_TYPE_MID\x10\x03\x12\x14\n\x10LANE_TYPE_JUNGLE\x10\x04\x12\x12\n\x0eLANE_TYPE_ROAM\x10\x05*\xc0\x01\n\nEBadgeType\x12\x1c\n\x18k_EBadgeType_TI7_Midweek\x10\x01\x12\x1b\n\x17k_EBadgeType_TI7_Finals\x10\x02\x12\x1d\n\x19k_EBadgeType_TI7_AllEvent\x10\x03\x12\x1c\n\x18k_EBadgeType_TI8_Midweek\x10\x04\x12\x1b\n\x17k_EBadgeType_TI8_Finals\x10\x05\x12\x1d\n\x19k_EBadgeType_TI8_AllEvent\x10\x06*\xd4\x01\n\rELeagueStatus\x12\x17\n\x13LEAGUE_STATUS_UNSET\x10\x00\x12\x1d\n\x19LEAGUE_STATUS_UNSUBMITTED\x10\x01\x12\x1b\n\x17LEAGUE_STATUS_SUBMITTED\x10\x02\x12\x1a\n\x16LEAGUE_STATUS_ACCEPTED\x10\x03\x12\x1a\n\x16LEAGUE_STATUS_REJECTED\x10\x04\x12\x1b\n\x17LEAGUE_STATUS_CONCLUDED\x10\x05\x12\x19\n\x15LEAGUE_STATUS_DELETED\x10\x06*\xb5\x01\n\rELeagueRegion\x12\x17\n\x13LEAGUE_REGION_UNSET\x10\x00\x12\x14\n\x10LEAGUE_REGION_NA\x10\x01\x12\x14\n\x10LEAGUE_REGION_SA\x10\x02\x12\x18\n\x14LEAGUE_REGION_EUROPE\x10\x03\x12\x15\n\x11LEAGUE_REGION_CIS\x10\x04\x12\x17\n\x13LEAGUE_REGION_CHINA\x10\x05\x12\x15\n\x11LEAGUE_REGION_SEA\x10\x06*\xa8\x01\n\x0b\x45LeagueTier\x12\x15\n\x11LEAGUE_TIER_UNSET\x10\x00\x12\x17\n\x13LEAGUE_TIER_AMATEUR\x10\x01\x12\x1c\n\x18LEAGUE_TIER_PROFESSIONAL\x10\x02\x12\x15\n\x11LEAGUE_TIER_MINOR\x10\x03\x12\x15\n\x11LEAGUE_TIER_MAJOR\x10\x04\x12\x1d\n\x19LEAGUE_TIER_INTERNATIONAL\x10\x05*|\n\x13\x45LeagueTierCategory\x12 \n\x1cLEAGUE_TIER_CATEGORY_AMATEUR\x10\x01\x12%\n!LEAGUE_TIER_CATEGORY_PROFESSIONAL\x10\x02\x12\x1c\n\x18LEAGUE_TIER_CATEGORY_DPC\x10\x03*\xa0\x01\n\x0c\x45LeagueFlags\x12\x15\n\x11LEAGUE_FLAGS_NONE\x10\x00\x12\x1d\n\x19LEAGUE_ACCEPTED_AGREEMENT\x10\x01\x12\x1d\n\x19LEAGUE_PAYMENT_EMAIL_SENT\x10\x02\x12\x1d\n\x19LEAGUE_COMPENDIUM_ALLOWED\x10\x04\x12\x1c\n\x18LEAGUE_COMPENDIUM_PUBLIC\x10\x08*\xab\x01\n\x18\x45LeagueBroadcastProvider\x12\x1c\n\x18LEAGUE_BROADCAST_UNKNOWN\x10\x00\x12\x1a\n\x16LEAGUE_BROADCAST_STEAM\x10\x01\x12\x1b\n\x17LEAGUE_BROADCAST_TWITCH\x10\x02\x12\x1c\n\x18LEAGUE_BROADCAST_YOUTUBE\x10\x03\x12\x1a\n\x16LEAGUE_BROADCAST_OTHER\x10\x64*\x86\x01\n\x0c\x45LeaguePhase\x12\x16\n\x12LEAGUE_PHASE_UNSET\x10\x00\x12#\n\x1fLEAGUE_PHASE_REGIONAL_QUALIFIER\x10\x01\x12\x1c\n\x18LEAGUE_PHASE_GROUP_STAGE\x10\x02\x12\x1b\n\x17LEAGUE_PHASE_MAIN_EVENT\x10\x03*\xc7\x02\n\x13\x45LeagueFantasyPhase\x12\x1e\n\x1aLEAGUE_FANTASY_PHASE_UNSET\x10\x00\x12\x1d\n\x19LEAGUE_FANTASY_PHASE_MAIN\x10\x01\x12%\n!LEAGUE_FANTASY_PHASE_QUALIFIER_NA\x10\x02\x12%\n!LEAGUE_FANTASY_PHASE_QUALIFIER_SA\x10\x03\x12)\n%LEAGUE_FANTASY_PHASE_QUALIFIER_EUROPE\x10\x04\x12&\n\"LEAGUE_FANTASY_PHASE_QUALIFIER_CIS\x10\x05\x12(\n$LEAGUE_FANTASY_PHASE_QUALIFIER_CHINA\x10\x06\x12&\n\"LEAGUE_FANTASY_PHASE_QUALIFIER_SEA\x10\x07*\xbb\r\n\x12\x45LeagueAuditAction\x12\x1f\n\x1bLEAGUE_AUDIT_ACTION_INVALID\x10\x00\x12%\n!LEAGUE_AUDIT_ACTION_LEAGUE_CREATE\x10\x01\x12#\n\x1fLEAGUE_AUDIT_ACTION_LEAGUE_EDIT\x10\x02\x12%\n!LEAGUE_AUDIT_ACTION_LEAGUE_DELETE\x10\x03\x12(\n$LEAGUE_AUDIT_ACTION_LEAGUE_ADMIN_ADD\x10\x04\x12+\n\'LEAGUE_AUDIT_ACTION_LEAGUE_ADMIN_REVOKE\x10\x05\x12,\n(LEAGUE_AUDIT_ACTION_LEAGUE_ADMIN_PROMOTE\x10\x06\x12)\n%LEAGUE_AUDIT_ACTION_LEAGUE_STREAM_ADD\x10\x07\x12,\n(LEAGUE_AUDIT_ACTION_LEAGUE_STREAM_REMOVE\x10\x08\x12,\n(LEAGUE_AUDIT_ACTION_LEAGUE_IMAGE_UPDATED\x10\t\x12,\n(LEAGUE_AUDIT_ACTION_LEAGUE_MESSAGE_ADDED\x10\n\x12(\n$LEAGUE_AUDIT_ACTION_LEAGUE_SUBMITTED\x10\x0b\x12-\n)LEAGUE_AUDIT_ACTION_LEAGUE_SET_PRIZE_POOL\x10\x0c\x12\x32\n.LEAGUE_AUDIT_ACTION_LEAGUE_ADD_PRIZE_POOL_ITEM\x10\r\x12\x35\n1LEAGUE_AUDIT_ACTION_LEAGUE_REMOVE_PRIZE_POOL_ITEM\x10\x0e\x12*\n&LEAGUE_AUDIT_ACTION_LEAGUE_MATCH_START\x10\x0f\x12(\n$LEAGUE_AUDIT_ACTION_LEAGUE_MATCH_END\x10\x10\x12/\n+LEAGUE_AUDIT_ACTION_LEAGUE_ADD_INVITED_TEAM\x10\x11\x12\x32\n.LEAGUE_AUDIT_ACTION_LEAGUE_REMOVE_INVITED_TEAM\x10\x12\x12-\n)LEAGUE_AUDIT_ACTION_LEAGUE_STATUS_CHANGED\x10\x13\x12*\n&LEAGUE_AUDIT_ACTION_LEAGUE_STREAM_EDIT\x10\x14\x12(\n$LEAGUE_AUDIT_ACTION_NODEGROUP_CREATE\x10\x64\x12)\n%LEAGUE_AUDIT_ACTION_NODEGROUP_DESTROY\x10\x65\x12*\n&LEAGUE_AUDIT_ACTION_NODEGROUP_ADD_TEAM\x10\x66\x12-\n)LEAGUE_AUDIT_ACTION_NODEGROUP_REMOVE_TEAM\x10g\x12/\n+LEAGUE_AUDIT_ACTION_NODEGROUP_SET_ADVANCING\x10h\x12&\n\"LEAGUE_AUDIT_ACTION_NODEGROUP_EDIT\x10i\x12*\n&LEAGUE_AUDIT_ACTION_NODEGROUP_POPULATE\x10j\x12+\n\'LEAGUE_AUDIT_ACTION_NODEGROUP_COMPLETED\x10k\x12$\n\x1fLEAGUE_AUDIT_ACTION_NODE_CREATE\x10\xc8\x01\x12%\n LEAGUE_AUDIT_ACTION_NODE_DESTROY\x10\xc9\x01\x12(\n#LEAGUE_AUDIT_ACTION_NODE_AUTOCREATE\x10\xca\x01\x12&\n!LEAGUE_AUDIT_ACTION_NODE_SET_TEAM\x10\xcb\x01\x12+\n&LEAGUE_AUDIT_ACTION_NODE_SET_SERIES_ID\x10\xcc\x01\x12+\n&LEAGUE_AUDIT_ACTION_NODE_SET_ADVANCING\x10\xcd\x01\x12&\n!LEAGUE_AUDIT_ACTION_NODE_SET_TIME\x10\xce\x01\x12-\n(LEAGUE_AUDIT_ACTION_NODE_MATCH_COMPLETED\x10\xcf\x01\x12\'\n\"LEAGUE_AUDIT_ACTION_NODE_COMPLETED\x10\xd0\x01\x12\"\n\x1dLEAGUE_AUDIT_ACTION_NODE_EDIT\x10\xd1\x01*\xbf\x0b\n\x14\x44OTA_COMBATLOG_TYPES\x12#\n\x16\x44OTA_COMBATLOG_INVALID\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x19\n\x15\x44OTA_COMBATLOG_DAMAGE\x10\x00\x12\x17\n\x13\x44OTA_COMBATLOG_HEAL\x10\x01\x12\x1f\n\x1b\x44OTA_COMBATLOG_MODIFIER_ADD\x10\x02\x12\"\n\x1e\x44OTA_COMBATLOG_MODIFIER_REMOVE\x10\x03\x12\x18\n\x14\x44OTA_COMBATLOG_DEATH\x10\x04\x12\x1a\n\x16\x44OTA_COMBATLOG_ABILITY\x10\x05\x12\x17\n\x13\x44OTA_COMBATLOG_ITEM\x10\x06\x12\x1b\n\x17\x44OTA_COMBATLOG_LOCATION\x10\x07\x12\x17\n\x13\x44OTA_COMBATLOG_GOLD\x10\x08\x12\x1d\n\x19\x44OTA_COMBATLOG_GAME_STATE\x10\t\x12\x15\n\x11\x44OTA_COMBATLOG_XP\x10\n\x12\x1b\n\x17\x44OTA_COMBATLOG_PURCHASE\x10\x0b\x12\x1a\n\x16\x44OTA_COMBATLOG_BUYBACK\x10\x0c\x12\"\n\x1e\x44OTA_COMBATLOG_ABILITY_TRIGGER\x10\r\x12\x1e\n\x1a\x44OTA_COMBATLOG_PLAYERSTATS\x10\x0e\x12\x1c\n\x18\x44OTA_COMBATLOG_MULTIKILL\x10\x0f\x12\x1d\n\x19\x44OTA_COMBATLOG_KILLSTREAK\x10\x10\x12%\n!DOTA_COMBATLOG_TEAM_BUILDING_KILL\x10\x11\x12\x1e\n\x1a\x44OTA_COMBATLOG_FIRST_BLOOD\x10\x12\x12\'\n#DOTA_COMBATLOG_MODIFIER_STACK_EVENT\x10\x13\x12%\n!DOTA_COMBATLOG_NEUTRAL_CAMP_STACK\x10\x14\x12\x1e\n\x1a\x44OTA_COMBATLOG_PICKUP_RUNE\x10\x15\x12%\n!DOTA_COMBATLOG_REVEALED_INVISIBLE\x10\x16\x12\x1d\n\x19\x44OTA_COMBATLOG_HERO_SAVED\x10\x17\x12 \n\x1c\x44OTA_COMBATLOG_MANA_RESTORED\x10\x18\x12\x1f\n\x1b\x44OTA_COMBATLOG_HERO_LEVELUP\x10\x19\x12#\n\x1f\x44OTA_COMBATLOG_BOTTLE_HEAL_ALLY\x10\x1a\x12 \n\x1c\x44OTA_COMBATLOG_ENDGAME_STATS\x10\x1b\x12$\n DOTA_COMBATLOG_INTERRUPT_CHANNEL\x10\x1c\x12\x1e\n\x1a\x44OTA_COMBATLOG_ALLIED_GOLD\x10\x1d\x12\x1e\n\x1a\x44OTA_COMBATLOG_AEGIS_TAKEN\x10\x1e\x12\x1e\n\x1a\x44OTA_COMBATLOG_MANA_DAMAGE\x10\x1f\x12,\n(DOTA_COMBATLOG_PHYSICAL_DAMAGE_PREVENTED\x10 \x12 \n\x1c\x44OTA_COMBATLOG_UNIT_SUMMONED\x10!\x12\x1f\n\x1b\x44OTA_COMBATLOG_ATTACK_EVADE\x10\"\x12\x1b\n\x17\x44OTA_COMBATLOG_TREE_CUT\x10#\x12\"\n\x1e\x44OTA_COMBATLOG_SUCCESSFUL_SCAN\x10$\x12!\n\x1d\x44OTA_COMBATLOG_END_KILLSTREAK\x10%\x12$\n DOTA_COMBATLOG_BLOODSTONE_CHARGE\x10&\x12\"\n\x1e\x44OTA_COMBATLOG_CRITICAL_DAMAGE\x10\'\x12\x1f\n\x1b\x44OTA_COMBATLOG_SPELL_ABSORB\x10(\x12\"\n\x1e\x44OTA_COMBATLOG_UNIT_TELEPORTED\x10)\x12#\n\x1f\x44OTA_COMBATLOG_KILL_EATER_EVENT\x10**u\n\x10\x45\x44PCFavoriteType\x12\x15\n\x11\x46\x41VORITE_TYPE_ALL\x10\x00\x12\x18\n\x14\x46\x41VORITE_TYPE_PLAYER\x10\x01\x12\x16\n\x12\x46\x41VORITE_TYPE_TEAM\x10\x02\x12\x18\n\x14\x46\x41VORITE_TYPE_LEAGUE\x10\x03*\xbc\x03\n\x14\x45\x44PCPushNotification\x12(\n$DPC_PUSH_NOTIFICATION_MATCH_STARTING\x10\x01\x12*\n&DPC_PUSH_NOTIFICATION_PLAYER_LEFT_TEAM\x10\n\x12,\n(DPC_PUSH_NOTIFICATION_PLAYER_JOINED_TEAM\x10\x0b\x12\'\n#DPC_PUSH_NOTIFICATION_LEAGUE_RESULT\x10\x14\x12\x36\n2DPC_PUSH_NOTIFICATION_PREDICTION_MATCHES_AVAILABLE\x10\x1e\x12+\n\'DPC_PUSH_NOTIFICATION_PREDICTION_RESULT\x10\x1f\x12\x30\n,DPC_PUSH_NOTIFICATION_FANTASY_PLAYER_CLEARED\x10(\x12/\n+DPC_PUSH_NOTIFICATION_FANTASY_DAILY_SUMMARY\x10)\x12/\n+DPC_PUSH_NOTIFICATION_FANTASY_FINAL_RESULTS\x10*B\x05H\x01\x90\x01\x00')
)

_DOTA_GAMEMODE = _descriptor.EnumDescriptor(
  name='DOTA_GameMode',
  full_name='dota.DOTA_GameMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_AP', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_CM', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_RD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_SD', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_AR', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_INTRO', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_HW', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_REVERSE_CM', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_XMAS', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_TUTORIAL', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_MO', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_LP', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_POOL1', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_FH', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_CUSTOM', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_CD', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_BD', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_ABILITY_DRAFT', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_EVENT', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_ARDM', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_1V1MID', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_ALL_DRAFT', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_TURBO', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_MUTATION', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMEMODE_COACHES_CHALLENGE', index=25, number=25,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2606,
  serialized_end=3272,
)
_sym_db.RegisterEnumDescriptor(_DOTA_GAMEMODE)

DOTA_GameMode = enum_type_wrapper.EnumTypeWrapper(_DOTA_GAMEMODE)
_DOTA_GAMESTATE = _descriptor.EnumDescriptor(
  name='DOTA_GameState',
  full_name='dota.DOTA_GameState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_INIT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_WAIT_FOR_PLAYERS_TO_LOAD', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_HERO_SELECTION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_STRATEGY_TIME', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_PRE_GAME', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_GAME_IN_PROGRESS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_POST_GAME', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_DISCONNECT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_TEAM_SHOWCASE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_CUSTOM_GAME_SETUP', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_WAIT_FOR_MAP_TO_LOAD', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GAMERULES_STATE_LAST', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3275,
  serialized_end=3767,
)
_sym_db.RegisterEnumDescriptor(_DOTA_GAMESTATE)

DOTA_GameState = enum_type_wrapper.EnumTypeWrapper(_DOTA_GAMESTATE)
_DOTA_GC_TEAM = _descriptor.EnumDescriptor(
  name='DOTA_GC_TEAM',
  full_name='dota.DOTA_GC_TEAM',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_GOOD_GUYS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_BAD_GUYS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_BROADCASTER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_SPECTATOR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_PLAYER_POOL', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_GC_TEAM_NOTEAM', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3770,
  serialized_end=3952,
)
_sym_db.RegisterEnumDescriptor(_DOTA_GC_TEAM)

DOTA_GC_TEAM = enum_type_wrapper.EnumTypeWrapper(_DOTA_GC_TEAM)
_EEVENT = _descriptor.EnumDescriptor(
  name='EEvent',
  full_name='dota.EEvent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_DIRETIDE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_SPRING_FESTIVAL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_FROSTIVUS_2013', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_COMPENDIUM_2014', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_NEXON_PC_BANG', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_PWRD_DAC_2015', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_NEW_BLOOM_2015', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_INTERNATIONAL_2015', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_FALL_MAJOR_2015', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_ORACLE_PA', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_NEW_BLOOM_2015_PREBEAST', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_FROSTIVUS', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_WINTER_MAJOR_2016', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_INTERNATIONAL_2016', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_FALL_MAJOR_2016', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_WINTER_MAJOR_2017', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_NEW_BLOOM_2017', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_INTERNATIONAL_2017', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_PLUS_SUBSCRIPTION', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_SINGLES_DAY_2017', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_FROSTIVUS_2017', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_INTERNATIONAL_2018', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_FROSTIVUS_2018', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_NEW_BLOOM_2019', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_INTERNATIONAL_2019', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_ID_COUNT', index=26, number=26,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3955,
  serialized_end=4753,
)
_sym_db.RegisterEnumDescriptor(_EEVENT)

EEvent = enum_type_wrapper.EnumTypeWrapper(_EEVENT)
_DOTALEAVERSTATUS_T = _descriptor.EnumDescriptor(
  name='DOTALeaverStatus_t',
  full_name='dota.DOTALeaverStatus_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_DISCONNECTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_DISCONNECTED_TOO_LONG', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_ABANDONED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_AFK', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_NEVER_CONNECTED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_NEVER_CONNECTED_TOO_LONG', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_FAILED_TO_READY_UP', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LEAVER_DECLINED', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4756,
  serialized_end=5052,
)
_sym_db.RegisterEnumDescriptor(_DOTALEAVERSTATUS_T)

DOTALeaverStatus_t = enum_type_wrapper.EnumTypeWrapper(_DOTALEAVERSTATUS_T)
_DOTACONNECTIONSTATE_T = _descriptor.EnumDescriptor(
  name='DOTAConnectionState_t',
  full_name='dota.DOTAConnectionState_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_NOT_YET_CONNECTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_CONNECTED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_DISCONNECTED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_ABANDONED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_LOADING', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CONNECTION_STATE_FAILED', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5055,
  serialized_end=5341,
)
_sym_db.RegisterEnumDescriptor(_DOTACONNECTIONSTATE_T)

DOTAConnectionState_t = enum_type_wrapper.EnumTypeWrapper(_DOTACONNECTIONSTATE_T)
_FANTASY_ROLES = _descriptor.EnumDescriptor(
  name='Fantasy_Roles',
  full_name='dota.Fantasy_Roles',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FANTASY_ROLE_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_ROLE_CORE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_ROLE_SUPPORT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_ROLE_OFFLANE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_ROLE_MID', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5344,
  serialized_end=5484,
)
_sym_db.RegisterEnumDescriptor(_FANTASY_ROLES)

Fantasy_Roles = enum_type_wrapper.EnumTypeWrapper(_FANTASY_ROLES)
_FANTASY_TEAM_SLOTS = _descriptor.EnumDescriptor(
  name='Fantasy_Team_Slots',
  full_name='dota.Fantasy_Team_Slots',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SLOT_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SLOT_CORE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SLOT_SUPPORT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SLOT_ANY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SLOT_BENCH', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5487,
  serialized_end=5625,
)
_sym_db.RegisterEnumDescriptor(_FANTASY_TEAM_SLOTS)

Fantasy_Team_Slots = enum_type_wrapper.EnumTypeWrapper(_FANTASY_TEAM_SLOTS)
_FANTASY_SELECTION_MODE = _descriptor.EnumDescriptor(
  name='Fantasy_Selection_Mode',
  full_name='dota.Fantasy_Selection_Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_LOCKED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_SHUFFLE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_FREE_PICK', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_ENDED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_PRE_SEASON', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_PRE_DRAFT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_DRAFTING', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_REGULAR_SEASON', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANTASY_SELECTION_CARD_BASED', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5628,
  serialized_end=5977,
)
_sym_db.RegisterEnumDescriptor(_FANTASY_SELECTION_MODE)

Fantasy_Selection_Mode = enum_type_wrapper.EnumTypeWrapper(_FANTASY_SELECTION_MODE)
_DOTACHATCHANNELTYPE_T = _descriptor.EnumDescriptor(
  name='DOTAChatChannelType_t',
  full_name='dota.DOTAChatChannelType_t',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Regional', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Custom', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Party', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Lobby', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Team', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Guild', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Fantasy', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Whisper', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Console', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Tab', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Invalid', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_GameAll', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_GameAllies', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_GameSpectator', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Cafe', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_CustomGame', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Private', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_PostGame', index=17, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_BattleCup', index=18, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_HLTVSpectator', index=19, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_GameEvents', index=20, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAChannelType_Trivia', index=21, number=22,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5980,
  serialized_end=6648,
)
_sym_db.RegisterEnumDescriptor(_DOTACHATCHANNELTYPE_T)

DOTAChatChannelType_t = enum_type_wrapper.EnumTypeWrapper(_DOTACHATCHANNELTYPE_T)
_EPROFILECARDSLOTTYPE = _descriptor.EnumDescriptor(
  name='EProfileCardSlotType',
  full_name='dota.EProfileCardSlotType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Empty', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Stat', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Trophy', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Item', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Hero', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Emoticon', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProfileCardSlotType_Team', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6651,
  serialized_end=6911,
)
_sym_db.RegisterEnumDescriptor(_EPROFILECARDSLOTTYPE)

EProfileCardSlotType = enum_type_wrapper.EnumTypeWrapper(_EPROFILECARDSLOTTYPE)
_EMATCHGROUPSERVERSTATUS = _descriptor.EnumDescriptor(
  name='EMatchGroupServerStatus',
  full_name='dota.EMatchGroupServerStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMatchGroupServerStatus_OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchGroupServerStatus_LimitedAvailability', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchGroupServerStatus_Offline', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6914,
  serialized_end=7063,
)
_sym_db.RegisterEnumDescriptor(_EMATCHGROUPSERVERSTATUS)

EMatchGroupServerStatus = enum_type_wrapper.EnumTypeWrapper(_EMATCHGROUPSERVERSTATUS)
_DOTA_CM_PICK = _descriptor.EnumDescriptor(
  name='DOTA_CM_PICK',
  full_name='dota.DOTA_CM_PICK',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_CM_RANDOM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CM_GOOD_GUYS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_CM_BAD_GUYS', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7065,
  serialized_end=7144,
)
_sym_db.RegisterEnumDescriptor(_DOTA_CM_PICK)

DOTA_CM_PICK = enum_type_wrapper.EnumTypeWrapper(_DOTA_CM_PICK)
_DOTALOWPRIORITYBANTYPE = _descriptor.EnumDescriptor(
  name='DOTALowPriorityBanType',
  full_name='dota.DOTALowPriorityBanType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_LOW_PRIORITY_BAN_ABANDON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LOW_PRIORITY_BAN_REPORTS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LOW_PRIORITY_BAN_SECONDARY_ABANDON', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7147,
  serialized_end=7286,
)
_sym_db.RegisterEnumDescriptor(_DOTALOWPRIORITYBANTYPE)

DOTALowPriorityBanType = enum_type_wrapper.EnumTypeWrapper(_DOTALOWPRIORITYBANTYPE)
_DOTALOBBYREADYSTATE = _descriptor.EnumDescriptor(
  name='DOTALobbyReadyState',
  full_name='dota.DOTALobbyReadyState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyReadyState_UNDECLARED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyReadyState_ACCEPTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyReadyState_DECLINED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7288,
  serialized_end=7413,
)
_sym_db.RegisterEnumDescriptor(_DOTALOBBYREADYSTATE)

DOTALobbyReadyState = enum_type_wrapper.EnumTypeWrapper(_DOTALOBBYREADYSTATE)
_DOTAGAMEVERSION = _descriptor.EnumDescriptor(
  name='DOTAGameVersion',
  full_name='dota.DOTAGameVersion',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GAME_VERSION_CURRENT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GAME_VERSION_STABLE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7415,
  serialized_end=7483,
)
_sym_db.RegisterEnumDescriptor(_DOTAGAMEVERSION)

DOTAGameVersion = enum_type_wrapper.EnumTypeWrapper(_DOTAGAMEVERSION)
_DOTAJOINLOBBYRESULT = _descriptor.EnumDescriptor(
  name='DOTAJoinLobbyResult',
  full_name='dota.DOTAJoinLobbyResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_ALREADY_IN_GAME', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_INVALID_LOBBY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_INCORRECT_PASSWORD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_ACCESS_DENIED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_GENERIC_ERROR', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_INCORRECT_VERSION', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_IN_TEAM_PARTY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_NO_LOBBY_FOUND', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_LOBBY_FULL', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_CUSTOM_GAME_INCORRECT_VERSION', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_TIMEOUT', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_CUSTOM_GAME_COOLDOWN', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_JOIN_RESULT_BUSY', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7486,
  serialized_end=8022,
)
_sym_db.RegisterEnumDescriptor(_DOTAJOINLOBBYRESULT)

DOTAJoinLobbyResult = enum_type_wrapper.EnumTypeWrapper(_DOTAJOINLOBBYRESULT)
_DOTASELECTIONPRIORITYRULES = _descriptor.EnumDescriptor(
  name='DOTASelectionPriorityRules',
  full_name='dota.DOTASelectionPriorityRules',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_DOTASelectionPriorityRules_Manual', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_DOTASelectionPriorityRules_Automatic', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8024,
  serialized_end=8137,
)
_sym_db.RegisterEnumDescriptor(_DOTASELECTIONPRIORITYRULES)

DOTASelectionPriorityRules = enum_type_wrapper.EnumTypeWrapper(_DOTASELECTIONPRIORITYRULES)
_DOTASELECTIONPRIORITYCHOICE = _descriptor.EnumDescriptor(
  name='DOTASelectionPriorityChoice',
  full_name='dota.DOTASelectionPriorityChoice',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_DOTASelectionPriorityChoice_Invalid', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_DOTASelectionPriorityChoice_FirstPick', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_DOTASelectionPriorityChoice_SecondPick', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_DOTASelectionPriorityChoice_Radiant', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_DOTASelectionPriorityChoice_Dire', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8140,
  serialized_end=8386,
)
_sym_db.RegisterEnumDescriptor(_DOTASELECTIONPRIORITYCHOICE)

DOTASelectionPriorityChoice = enum_type_wrapper.EnumTypeWrapper(_DOTASELECTIONPRIORITYCHOICE)
_DOTAMATCHVOTE = _descriptor.EnumDescriptor(
  name='DOTAMatchVote',
  full_name='dota.DOTAMatchVote',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTAMatchVote_INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAMatchVote_POSITIVE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTAMatchVote_NEGATIVE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8388,
  serialized_end=8486,
)
_sym_db.RegisterEnumDescriptor(_DOTAMATCHVOTE)

DOTAMatchVote = enum_type_wrapper.EnumTypeWrapper(_DOTAMATCHVOTE)
_DOTA_LOBBYMEMBERXPBONUS = _descriptor.EnumDescriptor(
  name='DOTA_LobbyMemberXPBonus',
  full_name='dota.DOTA_LobbyMemberXPBonus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_BATTLE_BOOSTER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_SHARE_BONUS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_PARTY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_RECRUITMENT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_LobbyMemberXPBonus_PCBANG', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8489,
  serialized_end=8748,
)
_sym_db.RegisterEnumDescriptor(_DOTA_LOBBYMEMBERXPBONUS)

DOTA_LobbyMemberXPBonus = enum_type_wrapper.EnumTypeWrapper(_DOTA_LOBBYMEMBERXPBONUS)
_DOTALOBBYVISIBILITY = _descriptor.EnumDescriptor(
  name='DOTALobbyVisibility',
  full_name='dota.DOTALobbyVisibility',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyVisibility_Public', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyVisibility_Friends', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTALobbyVisibility_Unlisted', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8750,
  serialized_end=8870,
)
_sym_db.RegisterEnumDescriptor(_DOTALOBBYVISIBILITY)

DOTALobbyVisibility = enum_type_wrapper.EnumTypeWrapper(_DOTALOBBYVISIBILITY)
_EDOTAPLAYERMMRTYPE = _descriptor.EnumDescriptor(
  name='EDOTAPlayerMMRType',
  full_name='dota.EDOTAPlayerMMRType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_Invalid', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_GeneralHidden', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_GeneralCompetitive2019', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_SoloCompetitive2019', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_1v1Competitive_UNUSED', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_GeneralSeasonalRanked', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_SoloSeasonalRanked', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_Competitive_Core', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EDOTAPlayerMMRType_Competitive_Support', index=8, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8873,
  serialized_end=9292,
)
_sym_db.RegisterEnumDescriptor(_EDOTAPLAYERMMRTYPE)

EDOTAPlayerMMRType = enum_type_wrapper.EnumTypeWrapper(_EDOTAPLAYERMMRTYPE)
_MATCHTYPE = _descriptor.EnumDescriptor(
  name='MatchType',
  full_name='dota.MatchType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_CASUAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_COOP_BOTS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_LEGACY_TEAM_RANKED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_LEGACY_SOLO_QUEUE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_COMPETITIVE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_WEEKEND_TOURNEY', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_CASUAL_1V1', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_EVENT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_SEASONAL_RANKED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_LOWPRI_DEPRECATED', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_STEAM_GROUP', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_MUTATION', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_TYPE_COACHES_CHALLENGE', index=12, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9295,
  serialized_end=9686,
)
_sym_db.RegisterEnumDescriptor(_MATCHTYPE)

MatchType = enum_type_wrapper.EnumTypeWrapper(_MATCHTYPE)
_DOTABOTDIFFICULTY = _descriptor.EnumDescriptor(
  name='DOTABotDifficulty',
  full_name='dota.DOTABotDifficulty',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_PASSIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_EASY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_MEDIUM', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_HARD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_UNFAIR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_INVALID', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_EXTRA1', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_EXTRA2', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOT_DIFFICULTY_EXTRA3', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9689,
  serialized_end=9949,
)
_sym_db.RegisterEnumDescriptor(_DOTABOTDIFFICULTY)

DOTABotDifficulty = enum_type_wrapper.EnumTypeWrapper(_DOTABOTDIFFICULTY)
_DOTA_BOT_MODE = _descriptor.EnumDescriptor(
  name='DOTA_BOT_MODE',
  full_name='dota.DOTA_BOT_MODE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_LANING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_ATTACK', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_ROAM', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_RETREAT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_SECRET_SHOP', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_SIDE_SHOP', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_RUNE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_PUSH_TOWER_TOP', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_PUSH_TOWER_MID', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_PUSH_TOWER_BOT', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_DEFEND_TOWER_TOP', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_DEFEND_TOWER_MID', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_DEFEND_TOWER_BOT', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_ASSEMBLE', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_ASSEMBLE_WITH_HUMANS', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_TEAM_ROAM', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_FARM', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_DEFEND_ALLY', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_EVASIVE_MANEUVERS', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_ROSHAN', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_ITEM', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_WARD', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_COMPANION', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_TUTORIAL_BOSS', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_BOT_MODE_MINION', index=25, number=25,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9952,
  serialized_end=10739,
)
_sym_db.RegisterEnumDescriptor(_DOTA_BOT_MODE)

DOTA_BOT_MODE = enum_type_wrapper.EnumTypeWrapper(_DOTA_BOT_MODE)
_MATCHLANGUAGES = _descriptor.EnumDescriptor(
  name='MatchLanguages',
  full_name='dota.MatchLanguages',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_ENGLISH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_RUSSIAN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_CHINESE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_KOREAN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_SPANISH', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_PORTUGUESE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCH_LANGUAGE_ENGLISH2', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10742,
  serialized_end=10985,
)
_sym_db.RegisterEnumDescriptor(_MATCHLANGUAGES)

MatchLanguages = enum_type_wrapper.EnumTypeWrapper(_MATCHLANGUAGES)
_ETOURNEYQUEUEDEADLINESTATE = _descriptor.EnumDescriptor(
  name='ETourneyQueueDeadlineState',
  full_name='dota.ETourneyQueueDeadlineState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_Normal', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_Missed', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_ExpiredOK', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_SeekingBye', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_EligibleForRefund', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_NA', index=5, number=-1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ETourneyQueueDeadlineState_ExpiringSoon', index=6, number=101,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10988,
  serialized_end=11332,
)
_sym_db.RegisterEnumDescriptor(_ETOURNEYQUEUEDEADLINESTATE)

ETourneyQueueDeadlineState = enum_type_wrapper.EnumTypeWrapper(_ETOURNEYQUEUEDEADLINESTATE)
_EMATCHOUTCOME = _descriptor.EnumDescriptor(
  name='EMatchOutcome',
  full_name='dota.EMatchOutcome',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_Unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_RadVictory', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_DireVictory', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_NotScored_PoorNetworkConditions', index=3, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_NotScored_Leaver', index=4, number=65,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_NotScored_ServerCrash', index=5, number=66,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_NotScored_NeverStarted', index=6, number=67,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMatchOutcome_NotScored_Canceled', index=7, number=68,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11335,
  serialized_end=11662,
)
_sym_db.RegisterEnumDescriptor(_EMATCHOUTCOME)

EMatchOutcome = enum_type_wrapper.EnumTypeWrapper(_EMATCHOUTCOME)
_ELANETYPE = _descriptor.EnumDescriptor(
  name='ELaneType',
  full_name='dota.ELaneType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LANE_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANE_TYPE_SAFE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANE_TYPE_OFF', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANE_TYPE_MID', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANE_TYPE_JUNGLE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANE_TYPE_ROAM', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11665,
  serialized_end=11799,
)
_sym_db.RegisterEnumDescriptor(_ELANETYPE)

ELaneType = enum_type_wrapper.EnumTypeWrapper(_ELANETYPE)
_EBADGETYPE = _descriptor.EnumDescriptor(
  name='EBadgeType',
  full_name='dota.EBadgeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EBadgeType_TI7_Midweek', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EBadgeType_TI7_Finals', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EBadgeType_TI7_AllEvent', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EBadgeType_TI8_Midweek', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EBadgeType_TI8_Finals', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EBadgeType_TI8_AllEvent', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11802,
  serialized_end=11994,
)
_sym_db.RegisterEnumDescriptor(_EBADGETYPE)

EBadgeType = enum_type_wrapper.EnumTypeWrapper(_EBADGETYPE)
_ELEAGUESTATUS = _descriptor.EnumDescriptor(
  name='ELeagueStatus',
  full_name='dota.ELeagueStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_STATUS_UNSUBMITTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_STATUS_SUBMITTED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_STATUS_ACCEPTED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_STATUS_REJECTED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_STATUS_CONCLUDED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_STATUS_DELETED', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11997,
  serialized_end=12209,
)
_sym_db.RegisterEnumDescriptor(_ELEAGUESTATUS)

ELeagueStatus = enum_type_wrapper.EnumTypeWrapper(_ELEAGUESTATUS)
_ELEAGUEREGION = _descriptor.EnumDescriptor(
  name='ELeagueRegion',
  full_name='dota.ELeagueRegion',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_REGION_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_REGION_NA', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_REGION_SA', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_REGION_EUROPE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_REGION_CIS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_REGION_CHINA', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_REGION_SEA', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12212,
  serialized_end=12393,
)
_sym_db.RegisterEnumDescriptor(_ELEAGUEREGION)

ELeagueRegion = enum_type_wrapper.EnumTypeWrapper(_ELEAGUEREGION)
_ELEAGUETIER = _descriptor.EnumDescriptor(
  name='ELeagueTier',
  full_name='dota.ELeagueTier',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_TIER_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_TIER_AMATEUR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_TIER_PROFESSIONAL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_TIER_MINOR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_TIER_MAJOR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_TIER_INTERNATIONAL', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12396,
  serialized_end=12564,
)
_sym_db.RegisterEnumDescriptor(_ELEAGUETIER)

ELeagueTier = enum_type_wrapper.EnumTypeWrapper(_ELEAGUETIER)
_ELEAGUETIERCATEGORY = _descriptor.EnumDescriptor(
  name='ELeagueTierCategory',
  full_name='dota.ELeagueTierCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_TIER_CATEGORY_AMATEUR', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_TIER_CATEGORY_PROFESSIONAL', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_TIER_CATEGORY_DPC', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12566,
  serialized_end=12690,
)
_sym_db.RegisterEnumDescriptor(_ELEAGUETIERCATEGORY)

ELeagueTierCategory = enum_type_wrapper.EnumTypeWrapper(_ELEAGUETIERCATEGORY)
_ELEAGUEFLAGS = _descriptor.EnumDescriptor(
  name='ELeagueFlags',
  full_name='dota.ELeagueFlags',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_FLAGS_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_ACCEPTED_AGREEMENT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_PAYMENT_EMAIL_SENT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_COMPENDIUM_ALLOWED', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_COMPENDIUM_PUBLIC', index=4, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12693,
  serialized_end=12853,
)
_sym_db.RegisterEnumDescriptor(_ELEAGUEFLAGS)

ELeagueFlags = enum_type_wrapper.EnumTypeWrapper(_ELEAGUEFLAGS)
_ELEAGUEBROADCASTPROVIDER = _descriptor.EnumDescriptor(
  name='ELeagueBroadcastProvider',
  full_name='dota.ELeagueBroadcastProvider',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_BROADCAST_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_BROADCAST_STEAM', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_BROADCAST_TWITCH', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_BROADCAST_YOUTUBE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_BROADCAST_OTHER', index=4, number=100,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12856,
  serialized_end=13027,
)
_sym_db.RegisterEnumDescriptor(_ELEAGUEBROADCASTPROVIDER)

ELeagueBroadcastProvider = enum_type_wrapper.EnumTypeWrapper(_ELEAGUEBROADCASTPROVIDER)
_ELEAGUEPHASE = _descriptor.EnumDescriptor(
  name='ELeaguePhase',
  full_name='dota.ELeaguePhase',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_PHASE_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_PHASE_REGIONAL_QUALIFIER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_PHASE_GROUP_STAGE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_PHASE_MAIN_EVENT', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13030,
  serialized_end=13164,
)
_sym_db.RegisterEnumDescriptor(_ELEAGUEPHASE)

ELeaguePhase = enum_type_wrapper.EnumTypeWrapper(_ELEAGUEPHASE)
_ELEAGUEFANTASYPHASE = _descriptor.EnumDescriptor(
  name='ELeagueFantasyPhase',
  full_name='dota.ELeagueFantasyPhase',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_FANTASY_PHASE_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_FANTASY_PHASE_MAIN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_FANTASY_PHASE_QUALIFIER_NA', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_FANTASY_PHASE_QUALIFIER_SA', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_FANTASY_PHASE_QUALIFIER_EUROPE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_FANTASY_PHASE_QUALIFIER_CIS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_FANTASY_PHASE_QUALIFIER_CHINA', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_FANTASY_PHASE_QUALIFIER_SEA', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13167,
  serialized_end=13494,
)
_sym_db.RegisterEnumDescriptor(_ELEAGUEFANTASYPHASE)

ELeagueFantasyPhase = enum_type_wrapper.EnumTypeWrapper(_ELEAGUEFANTASYPHASE)
_ELEAGUEAUDITACTION = _descriptor.EnumDescriptor(
  name='ELeagueAuditAction',
  full_name='dota.ELeagueAuditAction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_CREATE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_EDIT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_DELETE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_ADMIN_ADD', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_ADMIN_REVOKE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_ADMIN_PROMOTE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_STREAM_ADD', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_STREAM_REMOVE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_IMAGE_UPDATED', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_MESSAGE_ADDED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_SUBMITTED', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_SET_PRIZE_POOL', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_ADD_PRIZE_POOL_ITEM', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_REMOVE_PRIZE_POOL_ITEM', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_MATCH_START', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_MATCH_END', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_ADD_INVITED_TEAM', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_REMOVE_INVITED_TEAM', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_STATUS_CHANGED', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_LEAGUE_STREAM_EDIT', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODEGROUP_CREATE', index=21, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODEGROUP_DESTROY', index=22, number=101,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODEGROUP_ADD_TEAM', index=23, number=102,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODEGROUP_REMOVE_TEAM', index=24, number=103,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODEGROUP_SET_ADVANCING', index=25, number=104,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODEGROUP_EDIT', index=26, number=105,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODEGROUP_POPULATE', index=27, number=106,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODEGROUP_COMPLETED', index=28, number=107,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODE_CREATE', index=29, number=200,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODE_DESTROY', index=30, number=201,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODE_AUTOCREATE', index=31, number=202,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODE_SET_TEAM', index=32, number=203,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODE_SET_SERIES_ID', index=33, number=204,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODE_SET_ADVANCING', index=34, number=205,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODE_SET_TIME', index=35, number=206,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODE_MATCH_COMPLETED', index=36, number=207,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODE_COMPLETED', index=37, number=208,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEAGUE_AUDIT_ACTION_NODE_EDIT', index=38, number=209,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13497,
  serialized_end=15220,
)
_sym_db.RegisterEnumDescriptor(_ELEAGUEAUDITACTION)

ELeagueAuditAction = enum_type_wrapper.EnumTypeWrapper(_ELEAGUEAUDITACTION)
_DOTA_COMBATLOG_TYPES = _descriptor.EnumDescriptor(
  name='DOTA_COMBATLOG_TYPES',
  full_name='dota.DOTA_COMBATLOG_TYPES',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_INVALID', index=0, number=-1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_DAMAGE', index=1, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_HEAL', index=2, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MODIFIER_ADD', index=3, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MODIFIER_REMOVE', index=4, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_DEATH', index=5, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ABILITY', index=6, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ITEM', index=7, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_LOCATION', index=8, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_GOLD', index=9, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_GAME_STATE', index=10, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_XP', index=11, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_PURCHASE', index=12, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_BUYBACK', index=13, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ABILITY_TRIGGER', index=14, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_PLAYERSTATS', index=15, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MULTIKILL', index=16, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_KILLSTREAK', index=17, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_TEAM_BUILDING_KILL', index=18, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_FIRST_BLOOD', index=19, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MODIFIER_STACK_EVENT', index=20, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_NEUTRAL_CAMP_STACK', index=21, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_PICKUP_RUNE', index=22, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_REVEALED_INVISIBLE', index=23, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_HERO_SAVED', index=24, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MANA_RESTORED', index=25, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_HERO_LEVELUP', index=26, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_BOTTLE_HEAL_ALLY', index=27, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ENDGAME_STATS', index=28, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_INTERRUPT_CHANNEL', index=29, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ALLIED_GOLD', index=30, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_AEGIS_TAKEN', index=31, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_MANA_DAMAGE', index=32, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_PHYSICAL_DAMAGE_PREVENTED', index=33, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_UNIT_SUMMONED', index=34, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_ATTACK_EVADE', index=35, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_TREE_CUT', index=36, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_SUCCESSFUL_SCAN', index=37, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_END_KILLSTREAK', index=38, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_BLOODSTONE_CHARGE', index=39, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_CRITICAL_DAMAGE', index=40, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_SPELL_ABSORB', index=41, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_UNIT_TELEPORTED', index=42, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOTA_COMBATLOG_KILL_EATER_EVENT', index=43, number=42,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15223,
  serialized_end=16694,
)
_sym_db.RegisterEnumDescriptor(_DOTA_COMBATLOG_TYPES)

DOTA_COMBATLOG_TYPES = enum_type_wrapper.EnumTypeWrapper(_DOTA_COMBATLOG_TYPES)
_EDPCFAVORITETYPE = _descriptor.EnumDescriptor(
  name='EDPCFavoriteType',
  full_name='dota.EDPCFavoriteType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FAVORITE_TYPE_ALL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAVORITE_TYPE_PLAYER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAVORITE_TYPE_TEAM', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAVORITE_TYPE_LEAGUE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16696,
  serialized_end=16813,
)
_sym_db.RegisterEnumDescriptor(_EDPCFAVORITETYPE)

EDPCFavoriteType = enum_type_wrapper.EnumTypeWrapper(_EDPCFAVORITETYPE)
_EDPCPUSHNOTIFICATION = _descriptor.EnumDescriptor(
  name='EDPCPushNotification',
  full_name='dota.EDPCPushNotification',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DPC_PUSH_NOTIFICATION_MATCH_STARTING', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DPC_PUSH_NOTIFICATION_PLAYER_LEFT_TEAM', index=1, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DPC_PUSH_NOTIFICATION_PLAYER_JOINED_TEAM', index=2, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DPC_PUSH_NOTIFICATION_LEAGUE_RESULT', index=3, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DPC_PUSH_NOTIFICATION_PREDICTION_MATCHES_AVAILABLE', index=4, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DPC_PUSH_NOTIFICATION_PREDICTION_RESULT', index=5, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DPC_PUSH_NOTIFICATION_FANTASY_PLAYER_CLEARED', index=6, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DPC_PUSH_NOTIFICATION_FANTASY_DAILY_SUMMARY', index=7, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DPC_PUSH_NOTIFICATION_FANTASY_FINAL_RESULTS', index=8, number=42,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16816,
  serialized_end=17260,
)
_sym_db.RegisterEnumDescriptor(_EDPCPUSHNOTIFICATION)

EDPCPushNotification = enum_type_wrapper.EnumTypeWrapper(_EDPCPUSHNOTIFICATION)
DOTA_GAMEMODE_NONE = 0
DOTA_GAMEMODE_AP = 1
DOTA_GAMEMODE_CM = 2
DOTA_GAMEMODE_RD = 3
DOTA_GAMEMODE_SD = 4
DOTA_GAMEMODE_AR = 5
DOTA_GAMEMODE_INTRO = 6
DOTA_GAMEMODE_HW = 7
DOTA_GAMEMODE_REVERSE_CM = 8
DOTA_GAMEMODE_XMAS = 9
DOTA_GAMEMODE_TUTORIAL = 10
DOTA_GAMEMODE_MO = 11
DOTA_GAMEMODE_LP = 12
DOTA_GAMEMODE_POOL1 = 13
DOTA_GAMEMODE_FH = 14
DOTA_GAMEMODE_CUSTOM = 15
DOTA_GAMEMODE_CD = 16
DOTA_GAMEMODE_BD = 17
DOTA_GAMEMODE_ABILITY_DRAFT = 18
DOTA_GAMEMODE_EVENT = 19
DOTA_GAMEMODE_ARDM = 20
DOTA_GAMEMODE_1V1MID = 21
DOTA_GAMEMODE_ALL_DRAFT = 22
DOTA_GAMEMODE_TURBO = 23
DOTA_GAMEMODE_MUTATION = 24
DOTA_GAMEMODE_COACHES_CHALLENGE = 25
DOTA_GAMERULES_STATE_INIT = 0
DOTA_GAMERULES_STATE_WAIT_FOR_PLAYERS_TO_LOAD = 1
DOTA_GAMERULES_STATE_HERO_SELECTION = 2
DOTA_GAMERULES_STATE_STRATEGY_TIME = 3
DOTA_GAMERULES_STATE_PRE_GAME = 4
DOTA_GAMERULES_STATE_GAME_IN_PROGRESS = 5
DOTA_GAMERULES_STATE_POST_GAME = 6
DOTA_GAMERULES_STATE_DISCONNECT = 7
DOTA_GAMERULES_STATE_TEAM_SHOWCASE = 8
DOTA_GAMERULES_STATE_CUSTOM_GAME_SETUP = 9
DOTA_GAMERULES_STATE_WAIT_FOR_MAP_TO_LOAD = 10
DOTA_GAMERULES_STATE_LAST = 11
DOTA_GC_TEAM_GOOD_GUYS = 0
DOTA_GC_TEAM_BAD_GUYS = 1
DOTA_GC_TEAM_BROADCASTER = 2
DOTA_GC_TEAM_SPECTATOR = 3
DOTA_GC_TEAM_PLAYER_POOL = 4
DOTA_GC_TEAM_NOTEAM = 5
EVENT_ID_NONE = 0
EVENT_ID_DIRETIDE = 1
EVENT_ID_SPRING_FESTIVAL = 2
EVENT_ID_FROSTIVUS_2013 = 3
EVENT_ID_COMPENDIUM_2014 = 4
EVENT_ID_NEXON_PC_BANG = 5
EVENT_ID_PWRD_DAC_2015 = 6
EVENT_ID_NEW_BLOOM_2015 = 7
EVENT_ID_INTERNATIONAL_2015 = 8
EVENT_ID_FALL_MAJOR_2015 = 9
EVENT_ID_ORACLE_PA = 10
EVENT_ID_NEW_BLOOM_2015_PREBEAST = 11
EVENT_ID_FROSTIVUS = 12
EVENT_ID_WINTER_MAJOR_2016 = 13
EVENT_ID_INTERNATIONAL_2016 = 14
EVENT_ID_FALL_MAJOR_2016 = 15
EVENT_ID_WINTER_MAJOR_2017 = 16
EVENT_ID_NEW_BLOOM_2017 = 17
EVENT_ID_INTERNATIONAL_2017 = 18
EVENT_ID_PLUS_SUBSCRIPTION = 19
EVENT_ID_SINGLES_DAY_2017 = 20
EVENT_ID_FROSTIVUS_2017 = 21
EVENT_ID_INTERNATIONAL_2018 = 22
EVENT_ID_FROSTIVUS_2018 = 23
EVENT_ID_NEW_BLOOM_2019 = 24
EVENT_ID_INTERNATIONAL_2019 = 25
EVENT_ID_COUNT = 26
DOTA_LEAVER_NONE = 0
DOTA_LEAVER_DISCONNECTED = 1
DOTA_LEAVER_DISCONNECTED_TOO_LONG = 2
DOTA_LEAVER_ABANDONED = 3
DOTA_LEAVER_AFK = 4
DOTA_LEAVER_NEVER_CONNECTED = 5
DOTA_LEAVER_NEVER_CONNECTED_TOO_LONG = 6
DOTA_LEAVER_FAILED_TO_READY_UP = 7
DOTA_LEAVER_DECLINED = 8
DOTA_CONNECTION_STATE_UNKNOWN = 0
DOTA_CONNECTION_STATE_NOT_YET_CONNECTED = 1
DOTA_CONNECTION_STATE_CONNECTED = 2
DOTA_CONNECTION_STATE_DISCONNECTED = 3
DOTA_CONNECTION_STATE_ABANDONED = 4
DOTA_CONNECTION_STATE_LOADING = 5
DOTA_CONNECTION_STATE_FAILED = 6
FANTASY_ROLE_UNDEFINED = 0
FANTASY_ROLE_CORE = 1
FANTASY_ROLE_SUPPORT = 2
FANTASY_ROLE_OFFLANE = 3
FANTASY_ROLE_MID = 4
FANTASY_SLOT_NONE = 0
FANTASY_SLOT_CORE = 1
FANTASY_SLOT_SUPPORT = 2
FANTASY_SLOT_ANY = 3
FANTASY_SLOT_BENCH = 4
FANTASY_SELECTION_INVALID = 0
FANTASY_SELECTION_LOCKED = 1
FANTASY_SELECTION_SHUFFLE = 2
FANTASY_SELECTION_FREE_PICK = 3
FANTASY_SELECTION_ENDED = 4
FANTASY_SELECTION_PRE_SEASON = 5
FANTASY_SELECTION_PRE_DRAFT = 6
FANTASY_SELECTION_DRAFTING = 7
FANTASY_SELECTION_REGULAR_SEASON = 8
FANTASY_SELECTION_CARD_BASED = 9
DOTAChannelType_Regional = 0
DOTAChannelType_Custom = 1
DOTAChannelType_Party = 2
DOTAChannelType_Lobby = 3
DOTAChannelType_Team = 4
DOTAChannelType_Guild = 5
DOTAChannelType_Fantasy = 6
DOTAChannelType_Whisper = 7
DOTAChannelType_Console = 8
DOTAChannelType_Tab = 9
DOTAChannelType_Invalid = 10
DOTAChannelType_GameAll = 11
DOTAChannelType_GameAllies = 12
DOTAChannelType_GameSpectator = 13
DOTAChannelType_Cafe = 15
DOTAChannelType_CustomGame = 16
DOTAChannelType_Private = 17
DOTAChannelType_PostGame = 18
DOTAChannelType_BattleCup = 19
DOTAChannelType_HLTVSpectator = 20
DOTAChannelType_GameEvents = 21
DOTAChannelType_Trivia = 22
k_EProfileCardSlotType_Empty = 0
k_EProfileCardSlotType_Stat = 1
k_EProfileCardSlotType_Trophy = 2
k_EProfileCardSlotType_Item = 3
k_EProfileCardSlotType_Hero = 4
k_EProfileCardSlotType_Emoticon = 5
k_EProfileCardSlotType_Team = 6
k_EMatchGroupServerStatus_OK = 0
k_EMatchGroupServerStatus_LimitedAvailability = 1
k_EMatchGroupServerStatus_Offline = 2
DOTA_CM_RANDOM = 0
DOTA_CM_GOOD_GUYS = 1
DOTA_CM_BAD_GUYS = 2
DOTA_LOW_PRIORITY_BAN_ABANDON = 0
DOTA_LOW_PRIORITY_BAN_REPORTS = 1
DOTA_LOW_PRIORITY_BAN_SECONDARY_ABANDON = 2
DOTALobbyReadyState_UNDECLARED = 0
DOTALobbyReadyState_ACCEPTED = 1
DOTALobbyReadyState_DECLINED = 2
GAME_VERSION_CURRENT = 0
GAME_VERSION_STABLE = 1
DOTA_JOIN_RESULT_SUCCESS = 0
DOTA_JOIN_RESULT_ALREADY_IN_GAME = 1
DOTA_JOIN_RESULT_INVALID_LOBBY = 2
DOTA_JOIN_RESULT_INCORRECT_PASSWORD = 3
DOTA_JOIN_RESULT_ACCESS_DENIED = 4
DOTA_JOIN_RESULT_GENERIC_ERROR = 5
DOTA_JOIN_RESULT_INCORRECT_VERSION = 6
DOTA_JOIN_RESULT_IN_TEAM_PARTY = 7
DOTA_JOIN_RESULT_NO_LOBBY_FOUND = 8
DOTA_JOIN_RESULT_LOBBY_FULL = 9
DOTA_JOIN_RESULT_CUSTOM_GAME_INCORRECT_VERSION = 10
DOTA_JOIN_RESULT_TIMEOUT = 11
DOTA_JOIN_RESULT_CUSTOM_GAME_COOLDOWN = 12
DOTA_JOIN_RESULT_BUSY = 13
k_DOTASelectionPriorityRules_Manual = 0
k_DOTASelectionPriorityRules_Automatic = 1
k_DOTASelectionPriorityChoice_Invalid = 0
k_DOTASelectionPriorityChoice_FirstPick = 1
k_DOTASelectionPriorityChoice_SecondPick = 2
k_DOTASelectionPriorityChoice_Radiant = 3
k_DOTASelectionPriorityChoice_Dire = 4
DOTAMatchVote_INVALID = 0
DOTAMatchVote_POSITIVE = 1
DOTAMatchVote_NEGATIVE = 2
DOTA_LobbyMemberXPBonus_DEFAULT = 0
DOTA_LobbyMemberXPBonus_BATTLE_BOOSTER = 1
DOTA_LobbyMemberXPBonus_SHARE_BONUS = 2
DOTA_LobbyMemberXPBonus_PARTY = 3
DOTA_LobbyMemberXPBonus_RECRUITMENT = 4
DOTA_LobbyMemberXPBonus_PCBANG = 5
DOTALobbyVisibility_Public = 0
DOTALobbyVisibility_Friends = 1
DOTALobbyVisibility_Unlisted = 2
k_EDOTAPlayerMMRType_Invalid = 0
k_EDOTAPlayerMMRType_GeneralHidden = 1
k_EDOTAPlayerMMRType_GeneralCompetitive2019 = 3
k_EDOTAPlayerMMRType_SoloCompetitive2019 = 4
k_EDOTAPlayerMMRType_1v1Competitive_UNUSED = 5
k_EDOTAPlayerMMRType_GeneralSeasonalRanked = 6
k_EDOTAPlayerMMRType_SoloSeasonalRanked = 7
k_EDOTAPlayerMMRType_Competitive_Core = 8
k_EDOTAPlayerMMRType_Competitive_Support = 9
MATCH_TYPE_CASUAL = 0
MATCH_TYPE_COOP_BOTS = 1
MATCH_TYPE_LEGACY_TEAM_RANKED = 2
MATCH_TYPE_LEGACY_SOLO_QUEUE = 3
MATCH_TYPE_COMPETITIVE = 4
MATCH_TYPE_WEEKEND_TOURNEY = 5
MATCH_TYPE_CASUAL_1V1 = 6
MATCH_TYPE_EVENT = 7
MATCH_TYPE_SEASONAL_RANKED = 8
MATCH_TYPE_LOWPRI_DEPRECATED = 9
MATCH_TYPE_STEAM_GROUP = 10
MATCH_TYPE_MUTATION = 11
MATCH_TYPE_COACHES_CHALLENGE = 12
BOT_DIFFICULTY_PASSIVE = 0
BOT_DIFFICULTY_EASY = 1
BOT_DIFFICULTY_MEDIUM = 2
BOT_DIFFICULTY_HARD = 3
BOT_DIFFICULTY_UNFAIR = 4
BOT_DIFFICULTY_INVALID = 5
BOT_DIFFICULTY_EXTRA1 = 6
BOT_DIFFICULTY_EXTRA2 = 7
BOT_DIFFICULTY_EXTRA3 = 8
DOTA_BOT_MODE_NONE = 0
DOTA_BOT_MODE_LANING = 1
DOTA_BOT_MODE_ATTACK = 2
DOTA_BOT_MODE_ROAM = 3
DOTA_BOT_MODE_RETREAT = 4
DOTA_BOT_MODE_SECRET_SHOP = 5
DOTA_BOT_MODE_SIDE_SHOP = 6
DOTA_BOT_MODE_RUNE = 7
DOTA_BOT_MODE_PUSH_TOWER_TOP = 8
DOTA_BOT_MODE_PUSH_TOWER_MID = 9
DOTA_BOT_MODE_PUSH_TOWER_BOT = 10
DOTA_BOT_MODE_DEFEND_TOWER_TOP = 11
DOTA_BOT_MODE_DEFEND_TOWER_MID = 12
DOTA_BOT_MODE_DEFEND_TOWER_BOT = 13
DOTA_BOT_MODE_ASSEMBLE = 14
DOTA_BOT_MODE_ASSEMBLE_WITH_HUMANS = 15
DOTA_BOT_MODE_TEAM_ROAM = 16
DOTA_BOT_MODE_FARM = 17
DOTA_BOT_MODE_DEFEND_ALLY = 18
DOTA_BOT_MODE_EVASIVE_MANEUVERS = 19
DOTA_BOT_MODE_ROSHAN = 20
DOTA_BOT_MODE_ITEM = 21
DOTA_BOT_MODE_WARD = 22
DOTA_BOT_MODE_COMPANION = 23
DOTA_BOT_MODE_TUTORIAL_BOSS = 24
DOTA_BOT_MODE_MINION = 25
MATCH_LANGUAGE_INVALID = 0
MATCH_LANGUAGE_ENGLISH = 1
MATCH_LANGUAGE_RUSSIAN = 2
MATCH_LANGUAGE_CHINESE = 3
MATCH_LANGUAGE_KOREAN = 4
MATCH_LANGUAGE_SPANISH = 5
MATCH_LANGUAGE_PORTUGUESE = 6
MATCH_LANGUAGE_ENGLISH2 = 7
k_ETourneyQueueDeadlineState_Normal = 0
k_ETourneyQueueDeadlineState_Missed = 1
k_ETourneyQueueDeadlineState_ExpiredOK = 2
k_ETourneyQueueDeadlineState_SeekingBye = 3
k_ETourneyQueueDeadlineState_EligibleForRefund = 4
k_ETourneyQueueDeadlineState_NA = -1
k_ETourneyQueueDeadlineState_ExpiringSoon = 101
k_EMatchOutcome_Unknown = 0
k_EMatchOutcome_RadVictory = 2
k_EMatchOutcome_DireVictory = 3
k_EMatchOutcome_NotScored_PoorNetworkConditions = 64
k_EMatchOutcome_NotScored_Leaver = 65
k_EMatchOutcome_NotScored_ServerCrash = 66
k_EMatchOutcome_NotScored_NeverStarted = 67
k_EMatchOutcome_NotScored_Canceled = 68
LANE_TYPE_UNKNOWN = 0
LANE_TYPE_SAFE = 1
LANE_TYPE_OFF = 2
LANE_TYPE_MID = 3
LANE_TYPE_JUNGLE = 4
LANE_TYPE_ROAM = 5
k_EBadgeType_TI7_Midweek = 1
k_EBadgeType_TI7_Finals = 2
k_EBadgeType_TI7_AllEvent = 3
k_EBadgeType_TI8_Midweek = 4
k_EBadgeType_TI8_Finals = 5
k_EBadgeType_TI8_AllEvent = 6
LEAGUE_STATUS_UNSET = 0
LEAGUE_STATUS_UNSUBMITTED = 1
LEAGUE_STATUS_SUBMITTED = 2
LEAGUE_STATUS_ACCEPTED = 3
LEAGUE_STATUS_REJECTED = 4
LEAGUE_STATUS_CONCLUDED = 5
LEAGUE_STATUS_DELETED = 6
LEAGUE_REGION_UNSET = 0
LEAGUE_REGION_NA = 1
LEAGUE_REGION_SA = 2
LEAGUE_REGION_EUROPE = 3
LEAGUE_REGION_CIS = 4
LEAGUE_REGION_CHINA = 5
LEAGUE_REGION_SEA = 6
LEAGUE_TIER_UNSET = 0
LEAGUE_TIER_AMATEUR = 1
LEAGUE_TIER_PROFESSIONAL = 2
LEAGUE_TIER_MINOR = 3
LEAGUE_TIER_MAJOR = 4
LEAGUE_TIER_INTERNATIONAL = 5
LEAGUE_TIER_CATEGORY_AMATEUR = 1
LEAGUE_TIER_CATEGORY_PROFESSIONAL = 2
LEAGUE_TIER_CATEGORY_DPC = 3
LEAGUE_FLAGS_NONE = 0
LEAGUE_ACCEPTED_AGREEMENT = 1
LEAGUE_PAYMENT_EMAIL_SENT = 2
LEAGUE_COMPENDIUM_ALLOWED = 4
LEAGUE_COMPENDIUM_PUBLIC = 8
LEAGUE_BROADCAST_UNKNOWN = 0
LEAGUE_BROADCAST_STEAM = 1
LEAGUE_BROADCAST_TWITCH = 2
LEAGUE_BROADCAST_YOUTUBE = 3
LEAGUE_BROADCAST_OTHER = 100
LEAGUE_PHASE_UNSET = 0
LEAGUE_PHASE_REGIONAL_QUALIFIER = 1
LEAGUE_PHASE_GROUP_STAGE = 2
LEAGUE_PHASE_MAIN_EVENT = 3
LEAGUE_FANTASY_PHASE_UNSET = 0
LEAGUE_FANTASY_PHASE_MAIN = 1
LEAGUE_FANTASY_PHASE_QUALIFIER_NA = 2
LEAGUE_FANTASY_PHASE_QUALIFIER_SA = 3
LEAGUE_FANTASY_PHASE_QUALIFIER_EUROPE = 4
LEAGUE_FANTASY_PHASE_QUALIFIER_CIS = 5
LEAGUE_FANTASY_PHASE_QUALIFIER_CHINA = 6
LEAGUE_FANTASY_PHASE_QUALIFIER_SEA = 7
LEAGUE_AUDIT_ACTION_INVALID = 0
LEAGUE_AUDIT_ACTION_LEAGUE_CREATE = 1
LEAGUE_AUDIT_ACTION_LEAGUE_EDIT = 2
LEAGUE_AUDIT_ACTION_LEAGUE_DELETE = 3
LEAGUE_AUDIT_ACTION_LEAGUE_ADMIN_ADD = 4
LEAGUE_AUDIT_ACTION_LEAGUE_ADMIN_REVOKE = 5
LEAGUE_AUDIT_ACTION_LEAGUE_ADMIN_PROMOTE = 6
LEAGUE_AUDIT_ACTION_LEAGUE_STREAM_ADD = 7
LEAGUE_AUDIT_ACTION_LEAGUE_STREAM_REMOVE = 8
LEAGUE_AUDIT_ACTION_LEAGUE_IMAGE_UPDATED = 9
LEAGUE_AUDIT_ACTION_LEAGUE_MESSAGE_ADDED = 10
LEAGUE_AUDIT_ACTION_LEAGUE_SUBMITTED = 11
LEAGUE_AUDIT_ACTION_LEAGUE_SET_PRIZE_POOL = 12
LEAGUE_AUDIT_ACTION_LEAGUE_ADD_PRIZE_POOL_ITEM = 13
LEAGUE_AUDIT_ACTION_LEAGUE_REMOVE_PRIZE_POOL_ITEM = 14
LEAGUE_AUDIT_ACTION_LEAGUE_MATCH_START = 15
LEAGUE_AUDIT_ACTION_LEAGUE_MATCH_END = 16
LEAGUE_AUDIT_ACTION_LEAGUE_ADD_INVITED_TEAM = 17
LEAGUE_AUDIT_ACTION_LEAGUE_REMOVE_INVITED_TEAM = 18
LEAGUE_AUDIT_ACTION_LEAGUE_STATUS_CHANGED = 19
LEAGUE_AUDIT_ACTION_LEAGUE_STREAM_EDIT = 20
LEAGUE_AUDIT_ACTION_NODEGROUP_CREATE = 100
LEAGUE_AUDIT_ACTION_NODEGROUP_DESTROY = 101
LEAGUE_AUDIT_ACTION_NODEGROUP_ADD_TEAM = 102
LEAGUE_AUDIT_ACTION_NODEGROUP_REMOVE_TEAM = 103
LEAGUE_AUDIT_ACTION_NODEGROUP_SET_ADVANCING = 104
LEAGUE_AUDIT_ACTION_NODEGROUP_EDIT = 105
LEAGUE_AUDIT_ACTION_NODEGROUP_POPULATE = 106
LEAGUE_AUDIT_ACTION_NODEGROUP_COMPLETED = 107
LEAGUE_AUDIT_ACTION_NODE_CREATE = 200
LEAGUE_AUDIT_ACTION_NODE_DESTROY = 201
LEAGUE_AUDIT_ACTION_NODE_AUTOCREATE = 202
LEAGUE_AUDIT_ACTION_NODE_SET_TEAM = 203
LEAGUE_AUDIT_ACTION_NODE_SET_SERIES_ID = 204
LEAGUE_AUDIT_ACTION_NODE_SET_ADVANCING = 205
LEAGUE_AUDIT_ACTION_NODE_SET_TIME = 206
LEAGUE_AUDIT_ACTION_NODE_MATCH_COMPLETED = 207
LEAGUE_AUDIT_ACTION_NODE_COMPLETED = 208
LEAGUE_AUDIT_ACTION_NODE_EDIT = 209
DOTA_COMBATLOG_INVALID = -1
DOTA_COMBATLOG_DAMAGE = 0
DOTA_COMBATLOG_HEAL = 1
DOTA_COMBATLOG_MODIFIER_ADD = 2
DOTA_COMBATLOG_MODIFIER_REMOVE = 3
DOTA_COMBATLOG_DEATH = 4
DOTA_COMBATLOG_ABILITY = 5
DOTA_COMBATLOG_ITEM = 6
DOTA_COMBATLOG_LOCATION = 7
DOTA_COMBATLOG_GOLD = 8
DOTA_COMBATLOG_GAME_STATE = 9
DOTA_COMBATLOG_XP = 10
DOTA_COMBATLOG_PURCHASE = 11
DOTA_COMBATLOG_BUYBACK = 12
DOTA_COMBATLOG_ABILITY_TRIGGER = 13
DOTA_COMBATLOG_PLAYERSTATS = 14
DOTA_COMBATLOG_MULTIKILL = 15
DOTA_COMBATLOG_KILLSTREAK = 16
DOTA_COMBATLOG_TEAM_BUILDING_KILL = 17
DOTA_COMBATLOG_FIRST_BLOOD = 18
DOTA_COMBATLOG_MODIFIER_STACK_EVENT = 19
DOTA_COMBATLOG_NEUTRAL_CAMP_STACK = 20
DOTA_COMBATLOG_PICKUP_RUNE = 21
DOTA_COMBATLOG_REVEALED_INVISIBLE = 22
DOTA_COMBATLOG_HERO_SAVED = 23
DOTA_COMBATLOG_MANA_RESTORED = 24
DOTA_COMBATLOG_HERO_LEVELUP = 25
DOTA_COMBATLOG_BOTTLE_HEAL_ALLY = 26
DOTA_COMBATLOG_ENDGAME_STATS = 27
DOTA_COMBATLOG_INTERRUPT_CHANNEL = 28
DOTA_COMBATLOG_ALLIED_GOLD = 29
DOTA_COMBATLOG_AEGIS_TAKEN = 30
DOTA_COMBATLOG_MANA_DAMAGE = 31
DOTA_COMBATLOG_PHYSICAL_DAMAGE_PREVENTED = 32
DOTA_COMBATLOG_UNIT_SUMMONED = 33
DOTA_COMBATLOG_ATTACK_EVADE = 34
DOTA_COMBATLOG_TREE_CUT = 35
DOTA_COMBATLOG_SUCCESSFUL_SCAN = 36
DOTA_COMBATLOG_END_KILLSTREAK = 37
DOTA_COMBATLOG_BLOODSTONE_CHARGE = 38
DOTA_COMBATLOG_CRITICAL_DAMAGE = 39
DOTA_COMBATLOG_SPELL_ABSORB = 40
DOTA_COMBATLOG_UNIT_TELEPORTED = 41
DOTA_COMBATLOG_KILL_EATER_EVENT = 42
FAVORITE_TYPE_ALL = 0
FAVORITE_TYPE_PLAYER = 1
FAVORITE_TYPE_TEAM = 2
FAVORITE_TYPE_LEAGUE = 3
DPC_PUSH_NOTIFICATION_MATCH_STARTING = 1
DPC_PUSH_NOTIFICATION_PLAYER_LEFT_TEAM = 10
DPC_PUSH_NOTIFICATION_PLAYER_JOINED_TEAM = 11
DPC_PUSH_NOTIFICATION_LEAGUE_RESULT = 20
DPC_PUSH_NOTIFICATION_PREDICTION_MATCHES_AVAILABLE = 30
DPC_PUSH_NOTIFICATION_PREDICTION_RESULT = 31
DPC_PUSH_NOTIFICATION_FANTASY_PLAYER_CLEARED = 40
DPC_PUSH_NOTIFICATION_FANTASY_DAILY_SUMMARY = 41
DPC_PUSH_NOTIFICATION_FANTASY_FINAL_RESULTS = 42



_CDOTACLIENTHARDWARESPECS = _descriptor.Descriptor(
  name='CDOTAClientHardwareSpecs',
  full_name='dota.CDOTAClientHardwareSpecs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logical_processors', full_name='dota.CDOTAClientHardwareSpecs.logical_processors', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_cycles_per_second', full_name='dota.CDOTAClientHardwareSpecs.cpu_cycles_per_second', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_physical_memory', full_name='dota.CDOTAClientHardwareSpecs.total_physical_memory', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_64_bit_os', full_name='dota.CDOTAClientHardwareSpecs.is_64_bit_os', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_measurement', full_name='dota.CDOTAClientHardwareSpecs.upload_measurement', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefer_not_host', full_name='dota.CDOTAClientHardwareSpecs.prefer_not_host', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=225,
)


_CDOTASAVEGAME_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='dota.CDOTASaveGame.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team', full_name='dota.CDOTASaveGame.Player.team', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CDOTASaveGame.Player.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero', full_name='dota.CDOTASaveGame.Player.hero', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=479,
)

_CDOTASAVEGAME_SAVEINSTANCE_PLAYERPOSITIONS = _descriptor.Descriptor(
  name='PlayerPositions',
  full_name='dota.CDOTASaveGame.SaveInstance.PlayerPositions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='dota.CDOTASaveGame.SaveInstance.PlayerPositions.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='dota.CDOTASaveGame.SaveInstance.PlayerPositions.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=671,
  serialized_end=710,
)

_CDOTASAVEGAME_SAVEINSTANCE = _descriptor.Descriptor(
  name='SaveInstance',
  full_name='dota.CDOTASaveGame.SaveInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_time', full_name='dota.CDOTASaveGame.SaveInstance.game_time', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team1_score', full_name='dota.CDOTASaveGame.SaveInstance.team1_score', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team2_score', full_name='dota.CDOTASaveGame.SaveInstance.team2_score', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_positions', full_name='dota.CDOTASaveGame.SaveInstance.player_positions', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='save_id', full_name='dota.CDOTASaveGame.SaveInstance.save_id', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='save_time', full_name='dota.CDOTASaveGame.SaveInstance.save_time', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CDOTASAVEGAME_SAVEINSTANCE_PLAYERPOSITIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=710,
)

_CDOTASAVEGAME = _descriptor.Descriptor(
  name='CDOTASaveGame',
  full_name='dota.CDOTASaveGame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CDOTASaveGame.match_id', index=0,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='save_time', full_name='dota.CDOTASaveGame.save_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='players', full_name='dota.CDOTASaveGame.players', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='save_instances', full_name='dota.CDOTASaveGame.save_instances', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CDOTASAVEGAME_PLAYER, _CDOTASAVEGAME_SAVEINSTANCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=710,
)


_CMSGDOTACOMBATLOGENTRY = _descriptor.Descriptor(
  name='CMsgDOTACombatLogEntry',
  full_name='dota.CMsgDOTACombatLogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dota.CMsgDOTACombatLogEntry.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_name', full_name='dota.CMsgDOTACombatLogEntry.target_name', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_source_name', full_name='dota.CMsgDOTACombatLogEntry.target_source_name', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attacker_name', full_name='dota.CMsgDOTACombatLogEntry.attacker_name', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damage_source_name', full_name='dota.CMsgDOTACombatLogEntry.damage_source_name', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inflictor_name', full_name='dota.CMsgDOTACombatLogEntry.inflictor_name', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_attacker_illusion', full_name='dota.CMsgDOTACombatLogEntry.is_attacker_illusion', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_attacker_hero', full_name='dota.CMsgDOTACombatLogEntry.is_attacker_hero', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_target_illusion', full_name='dota.CMsgDOTACombatLogEntry.is_target_illusion', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_target_hero', full_name='dota.CMsgDOTACombatLogEntry.is_target_hero', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_visible_radiant', full_name='dota.CMsgDOTACombatLogEntry.is_visible_radiant', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_visible_dire', full_name='dota.CMsgDOTACombatLogEntry.is_visible_dire', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dota.CMsgDOTACombatLogEntry.value', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='health', full_name='dota.CMsgDOTACombatLogEntry.health', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='dota.CMsgDOTACombatLogEntry.timestamp', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stun_duration', full_name='dota.CMsgDOTACombatLogEntry.stun_duration', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slow_duration', full_name='dota.CMsgDOTACombatLogEntry.slow_duration', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_ability_toggle_on', full_name='dota.CMsgDOTACombatLogEntry.is_ability_toggle_on', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_ability_toggle_off', full_name='dota.CMsgDOTACombatLogEntry.is_ability_toggle_off', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ability_level', full_name='dota.CMsgDOTACombatLogEntry.ability_level', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_x', full_name='dota.CMsgDOTACombatLogEntry.location_x', index=20,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_y', full_name='dota.CMsgDOTACombatLogEntry.location_y', index=21,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gold_reason', full_name='dota.CMsgDOTACombatLogEntry.gold_reason', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp_raw', full_name='dota.CMsgDOTACombatLogEntry.timestamp_raw', index=23,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier_duration', full_name='dota.CMsgDOTACombatLogEntry.modifier_duration', index=24,
      number=25, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xp_reason', full_name='dota.CMsgDOTACombatLogEntry.xp_reason', index=25,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_hits', full_name='dota.CMsgDOTACombatLogEntry.last_hits', index=26,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attacker_team', full_name='dota.CMsgDOTACombatLogEntry.attacker_team', index=27,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_team', full_name='dota.CMsgDOTACombatLogEntry.target_team', index=28,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='obs_wards_placed', full_name='dota.CMsgDOTACombatLogEntry.obs_wards_placed', index=29,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assist_player0', full_name='dota.CMsgDOTACombatLogEntry.assist_player0', index=30,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assist_player1', full_name='dota.CMsgDOTACombatLogEntry.assist_player1', index=31,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assist_player2', full_name='dota.CMsgDOTACombatLogEntry.assist_player2', index=32,
      number=33, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assist_player3', full_name='dota.CMsgDOTACombatLogEntry.assist_player3', index=33,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stack_count', full_name='dota.CMsgDOTACombatLogEntry.stack_count', index=34,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_modifier', full_name='dota.CMsgDOTACombatLogEntry.hidden_modifier', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_target_building', full_name='dota.CMsgDOTACombatLogEntry.is_target_building', index=36,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neutral_camp_type', full_name='dota.CMsgDOTACombatLogEntry.neutral_camp_type', index=37,
      number=38, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rune_type', full_name='dota.CMsgDOTACombatLogEntry.rune_type', index=38,
      number=39, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assist_players', full_name='dota.CMsgDOTACombatLogEntry.assist_players', index=39,
      number=40, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_heal_save', full_name='dota.CMsgDOTACombatLogEntry.is_heal_save', index=40,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_ultimate_ability', full_name='dota.CMsgDOTACombatLogEntry.is_ultimate_ability', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attacker_hero_level', full_name='dota.CMsgDOTACombatLogEntry.attacker_hero_level', index=42,
      number=43, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_hero_level', full_name='dota.CMsgDOTACombatLogEntry.target_hero_level', index=43,
      number=44, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xpm', full_name='dota.CMsgDOTACombatLogEntry.xpm', index=44,
      number=45, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpm', full_name='dota.CMsgDOTACombatLogEntry.gpm', index=45,
      number=46, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_location', full_name='dota.CMsgDOTACombatLogEntry.event_location', index=46,
      number=47, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_is_self', full_name='dota.CMsgDOTACombatLogEntry.target_is_self', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damage_type', full_name='dota.CMsgDOTACombatLogEntry.damage_type', index=48,
      number=49, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invisibility_modifier', full_name='dota.CMsgDOTACombatLogEntry.invisibility_modifier', index=49,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damage_category', full_name='dota.CMsgDOTACombatLogEntry.damage_category', index=50,
      number=51, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='networth', full_name='dota.CMsgDOTACombatLogEntry.networth', index=51,
      number=52, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='building_type', full_name='dota.CMsgDOTACombatLogEntry.building_type', index=52,
      number=53, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier_elapsed_duration', full_name='dota.CMsgDOTACombatLogEntry.modifier_elapsed_duration', index=53,
      number=54, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='silence_modifier', full_name='dota.CMsgDOTACombatLogEntry.silence_modifier', index=54,
      number=55, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heal_from_lifesteal', full_name='dota.CMsgDOTACombatLogEntry.heal_from_lifesteal', index=55,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier_purged', full_name='dota.CMsgDOTACombatLogEntry.modifier_purged', index=56,
      number=57, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spell_evaded', full_name='dota.CMsgDOTACombatLogEntry.spell_evaded', index=57,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='motion_controller_modifier', full_name='dota.CMsgDOTACombatLogEntry.motion_controller_modifier', index=58,
      number=59, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_range_kill', full_name='dota.CMsgDOTACombatLogEntry.long_range_kill', index=59,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier_purge_ability', full_name='dota.CMsgDOTACombatLogEntry.modifier_purge_ability', index=60,
      number=61, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier_purge_npc', full_name='dota.CMsgDOTACombatLogEntry.modifier_purge_npc', index=61,
      number=62, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_modifier', full_name='dota.CMsgDOTACombatLogEntry.root_modifier', index=62,
      number=63, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_unit_death_count', full_name='dota.CMsgDOTACombatLogEntry.total_unit_death_count', index=63,
      number=64, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aura_modifier', full_name='dota.CMsgDOTACombatLogEntry.aura_modifier', index=64,
      number=65, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='armor_debuff_modifier', full_name='dota.CMsgDOTACombatLogEntry.armor_debuff_modifier', index=65,
      number=66, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_physical_damage_modifier', full_name='dota.CMsgDOTACombatLogEntry.no_physical_damage_modifier', index=66,
      number=67, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier_ability', full_name='dota.CMsgDOTACombatLogEntry.modifier_ability', index=67,
      number=68, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier_hidden', full_name='dota.CMsgDOTACombatLogEntry.modifier_hidden', index=68,
      number=69, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inflictor_is_stolen_ability', full_name='dota.CMsgDOTACombatLogEntry.inflictor_is_stolen_ability', index=69,
      number=70, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kill_eater_event', full_name='dota.CMsgDOTACombatLogEntry.kill_eater_event', index=70,
      number=71, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit_status_label', full_name='dota.CMsgDOTACombatLogEntry.unit_status_label', index=71,
      number=72, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spell_generated_attack', full_name='dota.CMsgDOTACombatLogEntry.spell_generated_attack', index=72,
      number=73, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=2603,
)

_CDOTASAVEGAME_PLAYER.fields_by_name['team'].enum_type = _DOTA_GC_TEAM
_CDOTASAVEGAME_PLAYER.containing_type = _CDOTASAVEGAME
_CDOTASAVEGAME_SAVEINSTANCE_PLAYERPOSITIONS.containing_type = _CDOTASAVEGAME_SAVEINSTANCE
_CDOTASAVEGAME_SAVEINSTANCE.fields_by_name['player_positions'].message_type = _CDOTASAVEGAME_SAVEINSTANCE_PLAYERPOSITIONS
_CDOTASAVEGAME_SAVEINSTANCE.containing_type = _CDOTASAVEGAME
_CDOTASAVEGAME.fields_by_name['players'].message_type = _CDOTASAVEGAME_PLAYER
_CDOTASAVEGAME.fields_by_name['save_instances'].message_type = _CDOTASAVEGAME_SAVEINSTANCE
_CMSGDOTACOMBATLOGENTRY.fields_by_name['type'].enum_type = _DOTA_COMBATLOG_TYPES
DESCRIPTOR.message_types_by_name['CDOTAClientHardwareSpecs'] = _CDOTACLIENTHARDWARESPECS
DESCRIPTOR.message_types_by_name['CDOTASaveGame'] = _CDOTASAVEGAME
DESCRIPTOR.message_types_by_name['CMsgDOTACombatLogEntry'] = _CMSGDOTACOMBATLOGENTRY
DESCRIPTOR.enum_types_by_name['DOTA_GameMode'] = _DOTA_GAMEMODE
DESCRIPTOR.enum_types_by_name['DOTA_GameState'] = _DOTA_GAMESTATE
DESCRIPTOR.enum_types_by_name['DOTA_GC_TEAM'] = _DOTA_GC_TEAM
DESCRIPTOR.enum_types_by_name['EEvent'] = _EEVENT
DESCRIPTOR.enum_types_by_name['DOTALeaverStatus_t'] = _DOTALEAVERSTATUS_T
DESCRIPTOR.enum_types_by_name['DOTAConnectionState_t'] = _DOTACONNECTIONSTATE_T
DESCRIPTOR.enum_types_by_name['Fantasy_Roles'] = _FANTASY_ROLES
DESCRIPTOR.enum_types_by_name['Fantasy_Team_Slots'] = _FANTASY_TEAM_SLOTS
DESCRIPTOR.enum_types_by_name['Fantasy_Selection_Mode'] = _FANTASY_SELECTION_MODE
DESCRIPTOR.enum_types_by_name['DOTAChatChannelType_t'] = _DOTACHATCHANNELTYPE_T
DESCRIPTOR.enum_types_by_name['EProfileCardSlotType'] = _EPROFILECARDSLOTTYPE
DESCRIPTOR.enum_types_by_name['EMatchGroupServerStatus'] = _EMATCHGROUPSERVERSTATUS
DESCRIPTOR.enum_types_by_name['DOTA_CM_PICK'] = _DOTA_CM_PICK
DESCRIPTOR.enum_types_by_name['DOTALowPriorityBanType'] = _DOTALOWPRIORITYBANTYPE
DESCRIPTOR.enum_types_by_name['DOTALobbyReadyState'] = _DOTALOBBYREADYSTATE
DESCRIPTOR.enum_types_by_name['DOTAGameVersion'] = _DOTAGAMEVERSION
DESCRIPTOR.enum_types_by_name['DOTAJoinLobbyResult'] = _DOTAJOINLOBBYRESULT
DESCRIPTOR.enum_types_by_name['DOTASelectionPriorityRules'] = _DOTASELECTIONPRIORITYRULES
DESCRIPTOR.enum_types_by_name['DOTASelectionPriorityChoice'] = _DOTASELECTIONPRIORITYCHOICE
DESCRIPTOR.enum_types_by_name['DOTAMatchVote'] = _DOTAMATCHVOTE
DESCRIPTOR.enum_types_by_name['DOTA_LobbyMemberXPBonus'] = _DOTA_LOBBYMEMBERXPBONUS
DESCRIPTOR.enum_types_by_name['DOTALobbyVisibility'] = _DOTALOBBYVISIBILITY
DESCRIPTOR.enum_types_by_name['EDOTAPlayerMMRType'] = _EDOTAPLAYERMMRTYPE
DESCRIPTOR.enum_types_by_name['MatchType'] = _MATCHTYPE
DESCRIPTOR.enum_types_by_name['DOTABotDifficulty'] = _DOTABOTDIFFICULTY
DESCRIPTOR.enum_types_by_name['DOTA_BOT_MODE'] = _DOTA_BOT_MODE
DESCRIPTOR.enum_types_by_name['MatchLanguages'] = _MATCHLANGUAGES
DESCRIPTOR.enum_types_by_name['ETourneyQueueDeadlineState'] = _ETOURNEYQUEUEDEADLINESTATE
DESCRIPTOR.enum_types_by_name['EMatchOutcome'] = _EMATCHOUTCOME
DESCRIPTOR.enum_types_by_name['ELaneType'] = _ELANETYPE
DESCRIPTOR.enum_types_by_name['EBadgeType'] = _EBADGETYPE
DESCRIPTOR.enum_types_by_name['ELeagueStatus'] = _ELEAGUESTATUS
DESCRIPTOR.enum_types_by_name['ELeagueRegion'] = _ELEAGUEREGION
DESCRIPTOR.enum_types_by_name['ELeagueTier'] = _ELEAGUETIER
DESCRIPTOR.enum_types_by_name['ELeagueTierCategory'] = _ELEAGUETIERCATEGORY
DESCRIPTOR.enum_types_by_name['ELeagueFlags'] = _ELEAGUEFLAGS
DESCRIPTOR.enum_types_by_name['ELeagueBroadcastProvider'] = _ELEAGUEBROADCASTPROVIDER
DESCRIPTOR.enum_types_by_name['ELeaguePhase'] = _ELEAGUEPHASE
DESCRIPTOR.enum_types_by_name['ELeagueFantasyPhase'] = _ELEAGUEFANTASYPHASE
DESCRIPTOR.enum_types_by_name['ELeagueAuditAction'] = _ELEAGUEAUDITACTION
DESCRIPTOR.enum_types_by_name['DOTA_COMBATLOG_TYPES'] = _DOTA_COMBATLOG_TYPES
DESCRIPTOR.enum_types_by_name['EDPCFavoriteType'] = _EDPCFAVORITETYPE
DESCRIPTOR.enum_types_by_name['EDPCPushNotification'] = _EDPCPUSHNOTIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CDOTAClientHardwareSpecs = _reflection.GeneratedProtocolMessageType('CDOTAClientHardwareSpecs', (_message.Message,), dict(
  DESCRIPTOR = _CDOTACLIENTHARDWARESPECS,
  __module__ = 'dota_shared_enums_pb2'
  # @@protoc_insertion_point(class_scope:dota.CDOTAClientHardwareSpecs)
  ))
_sym_db.RegisterMessage(CDOTAClientHardwareSpecs)

CDOTASaveGame = _reflection.GeneratedProtocolMessageType('CDOTASaveGame', (_message.Message,), dict(

  Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
    DESCRIPTOR = _CDOTASAVEGAME_PLAYER,
    __module__ = 'dota_shared_enums_pb2'
    # @@protoc_insertion_point(class_scope:dota.CDOTASaveGame.Player)
    ))
  ,

  SaveInstance = _reflection.GeneratedProtocolMessageType('SaveInstance', (_message.Message,), dict(

    PlayerPositions = _reflection.GeneratedProtocolMessageType('PlayerPositions', (_message.Message,), dict(
      DESCRIPTOR = _CDOTASAVEGAME_SAVEINSTANCE_PLAYERPOSITIONS,
      __module__ = 'dota_shared_enums_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTASaveGame.SaveInstance.PlayerPositions)
      ))
    ,
    DESCRIPTOR = _CDOTASAVEGAME_SAVEINSTANCE,
    __module__ = 'dota_shared_enums_pb2'
    # @@protoc_insertion_point(class_scope:dota.CDOTASaveGame.SaveInstance)
    ))
  ,
  DESCRIPTOR = _CDOTASAVEGAME,
  __module__ = 'dota_shared_enums_pb2'
  # @@protoc_insertion_point(class_scope:dota.CDOTASaveGame)
  ))
_sym_db.RegisterMessage(CDOTASaveGame)
_sym_db.RegisterMessage(CDOTASaveGame.Player)
_sym_db.RegisterMessage(CDOTASaveGame.SaveInstance)
_sym_db.RegisterMessage(CDOTASaveGame.SaveInstance.PlayerPositions)

CMsgDOTACombatLogEntry = _reflection.GeneratedProtocolMessageType('CMsgDOTACombatLogEntry', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTACOMBATLOGENTRY,
  __module__ = 'dota_shared_enums_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTACombatLogEntry)
  ))
_sym_db.RegisterMessage(CMsgDOTACombatLogEntry)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
